import os
import math
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from ui.systembutton import *
import configparser
from models.enums import CONF_PATH
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Set_Widget(QWidget):
    def __init__(self,software_store_auto_update,software_auto_update,notice_software_update,parent = None):
        QWidget.__init__(self, parent)
        self.mouse_press = False
        self.software_store_auto_update = software_store_auto_update
        self.software_auto_update = software_auto_update
        self.notice_software_update = notice_software_update
        self.init_ui()
        self.paintEvent = self.set_paintEvent

    def init_ui(self):
        self.setFixedSize(442,450)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool)
        self.setWindowTitle(_("Software Store"))
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.widget = QWidget(self)
        self.widget.resize(424,432)
        self.widget.move(9,9)
        #self.widget.setStyleSheet("QWidget{background: rgba(255, 255, 255, 0.7);border-radius:12px;background-color:#ffffff;}")
        self.title_label = QLabel(self.widget)
        self.title_label.setFixedSize(170,16)
        self.title_label.setText(_("Set"))
        self.title_label.setStyleSheet("QLabel{border:0px;font-size: 14px;color: #1B1B1B;font-weight: 500;line-height: 14px;}")
        self.title_label.move(16,12)

        self.auto_update_label = QLabel(self.widget)
        self.auto_update_label.setAttribute(Qt.WA_TranslucentBackground)
        self.auto_update_label.setFixedHeight(20)
        self.auto_update_label.setText(_("Auto update:"))
        self.auto_update_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.auto_update_label.adjustSize()
        self.auto_update_label.move(16,55)

        self.check_btn1 = QCheckBox(self.widget)
        self.check_btn1.setFocusPolicy(Qt.NoFocus)
        self.check_btn1.resize(16,16)
        self.check_btn1.setStyleSheet(
            "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
            "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
            "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
            "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
            "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
            "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
            "QCheckBox::indicator{width: 16px;height: 16px;}" \
            "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
            "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
            "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
        self.check_btn1.move(self.auto_update_label.x()+self.auto_update_label.width()+2,int((self.auto_update_label.height()-self.check_btn1.height())/2) + self.auto_update_label.y())
        if(self.software_store_auto_update == "True"):
            self.check_btn1.setChecked(True)

        self.auto_update_uksc_label = QLabel(self.widget)
        self.auto_update_uksc_label.setAttribute(Qt.WA_TranslucentBackground)
        self.auto_update_uksc_label.setFixedHeight(20)
        self.auto_update_uksc_label.setText(_("Auto update software store"))
        self.auto_update_uksc_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.auto_update_uksc_label.move(self.check_btn1.x()+self.check_btn1.width()+8,int((self.check_btn1.height()-self.auto_update_uksc_label.height())/2)+self.check_btn1.y())
        self.auto_update_uksc_label.adjustSize()

        self.auto_update_uksc_tip_label = QLabel(self.widget)
        self.auto_update_uksc_tip_label.setAttribute(Qt.WA_TranslucentBackground)
        self.auto_update_uksc_tip_label.setFixedHeight(20)
        self.auto_update_uksc_tip_label.setText(_("When the software store has a new version, it will be updated automatically"))
        self.auto_update_uksc_tip_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #999999;line-height: 20px;}")
        self.auto_update_uksc_tip_label.move(self.auto_update_uksc_label.x(), self.auto_update_uksc_label.y()+self.auto_update_uksc_label.height()+4)
        self.auto_update_uksc_tip_label.adjustSize()

        self.check_btn2 = QCheckBox(self.widget)
        self.check_btn2.setFocusPolicy(Qt.NoFocus)
        self.check_btn2.resize(16, 16)
        self.check_btn2.setStyleSheet(
            "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
            "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
            "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
            "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
            "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
            "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
            "QCheckBox::indicator{width: 16px;height: 16px;}" \
            "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
            "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
            "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
        self.check_btn2.move(self.check_btn1.x(), self.auto_update_uksc_tip_label.y()+self.auto_update_uksc_tip_label.height()+10)
        self.check_btn2.stateChanged.connect(self.change_check_btn_statue)
        if(self.software_auto_update == "True"):
            self.check_btn2.setChecked(True)

        self.auto_update_software_label = QLabel(self.widget)
        self.auto_update_software_label.setAttribute(Qt.WA_TranslucentBackground)
        self.auto_update_software_label.setFixedHeight(20)
        self.auto_update_software_label.setText(_("Auto update software"))
        self.auto_update_software_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.auto_update_software_label.move(self.check_btn2.x() + self.check_btn2.width() + 8, int((self.check_btn2.height() - self.auto_update_software_label.height()) / 2) + self.check_btn2.y())
        self.auto_update_software_label.adjustSize()

        self.auto_update_software_tip_label = QLabel(self.widget)
        self.auto_update_software_tip_label.setAttribute(Qt.WA_TranslucentBackground)
        self.auto_update_software_tip_label.setFixedHeight(20)
        self.auto_update_software_tip_label.setText(_("Software installed through the store will be automatically updated"))
        self.auto_update_software_tip_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #999999;line-height: 20px;}")
        self.auto_update_software_tip_label.move(self.auto_update_software_label.x(),self.auto_update_software_label.y() + self.auto_update_software_label.height() + 4)
        self.auto_update_software_tip_label.adjustSize()

        if (self.auto_update_software_tip_label.width() > self.auto_update_uksc_tip_label.width()):
            self.widget.setFixedWidth(self.auto_update_software_tip_label.x() + self.auto_update_software_tip_label.width() + 30)
            self.setFixedWidth(self.widget.width() + 18)
        else:
            if (self.auto_update_uksc_tip_label.x() + self.auto_update_uksc_tip_label.width() + 30 > self.widget.width()):
                self.widget.setFixedWidth(self.auto_update_uksc_tip_label.x() + self.auto_update_uksc_tip_label.width() + 30)
                self.setFixedWidth(self.widget.width() + 18)


        self.line_label = QLabel(self.widget)
        self.line_label.setFixedSize(self.widget.width() - 2, 1)
        self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
        self.line_label.move(1, 38)

        self.line_label1 = QLabel(self.widget)
        self.line_label1.setFixedSize(self.widget.width()-16*2, 1)
        self.line_label1.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
        self.line_label1.move(16, 167)

        self.notice_label = QLabel(self.widget)
        self.notice_label.setAttribute(Qt.WA_TranslucentBackground)
        self.notice_label.setFixedHeight(20)
        self.notice_label.setText(_("notice:"))
        self.notice_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.notice_label.adjustSize()
        self.notice_label.move(self.auto_update_label.width()-self.notice_label.width()+self.auto_update_label.x(), self.line_label1.y()+self.line_label1.height()+16)

        self.check_btn3 = QCheckBox(self.widget)
        self.check_btn3.setFocusPolicy(Qt.NoFocus)
        self.check_btn3.resize(16, 16)
        self.check_btn3.setStyleSheet(
            "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
            "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
            "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
            "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
            "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
            "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
            "QCheckBox::indicator{width: 16px;height: 16px;}" \
            "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
            "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
            "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
        self.check_btn3.move(self.notice_label.x() + self.notice_label.width() + 2, int(
            (self.notice_label.height() - self.check_btn3.height()) / 2) + self.notice_label.y())
        if (self.software_auto_update == "True"):
            try:
                cf = configparser.ConfigParser()
                cf.read(CONF_PATH)
                try:
                    cf.set("option-settings", "notice-software-update", "False")
                    with open(CONF_PATH, "w+") as f:
                        cf.write(f)
                except:
                    pass
            except:
                pass
            self.change_check_btn_statue(2)
        else:
            if(self.notice_software_update == "True"):
                self.check_btn3.setChecked(True)


        self.notice_software_update_label = QLabel(self.widget)
        self.notice_software_update_label.setAttribute(Qt.WA_TranslucentBackground)
        self.notice_software_update_label.setFixedHeight(20)
        self.notice_software_update_label.setText(_("Allow software update notifications"))
        self.notice_software_update_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.notice_software_update_label.move(self.check_btn3.x() + self.check_btn3.width() + 8, int(
            (self.check_btn3.height() - self.notice_software_update_label.height()) / 2) + self.check_btn3.y())
        self.notice_software_update_label.adjustSize()

        self.line_label2 = QLabel(self.widget)
        self.line_label2.setFixedSize(self.widget.width()-16*2, 1)
        self.line_label2.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
        self.line_label2.move(16, 325)
        self.line_label2.hide()

        self.btn = QPushButton(self.widget)
        self.btn.setFocusPolicy(Qt.NoFocus)
        self.btn.setFixedSize(64,30)
        self.btn.setStyleSheet("QPushButton{background: #3790FA;border-radius: 6px;font-size: 14px;font-weight: 400;color: #FFFFFF;text-align: center;line-height: 12px;}QPushButton:hover{background: #40A9FB;;border-radius: 6px;color: #ffffff;}QPushButton:pressed{background: #296CD9;border-radius: 6px;color: #ffffff;}")
        self.btn.setText(_("OK"))
        self.btn.move(self.widget.width()-self.btn.width()-16,self.notice_label.y()+self.notice_label.height()+16)

        self.cancel_btn = QPushButton(self.widget)
        self.cancel_btn.setFocusPolicy(Qt.NoFocus)
        self.cancel_btn.setFixedSize(64, 30)
        self.cancel_btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;border-radius: 6px;text-align: center;border: 1px solid #DDDFE7;}QPushButton:hover{background: #F2F6FD;border-radius: 6px;border: 1px solid #DDDFE7;}QPushButton:pressed{background: #F2F6FD;border-radius: 6px;border: 1px solid #DDDFE7;}")
        self.cancel_btn.setText(_("cancel"))
        self.cancel_btn.move(self.btn.x()-self.cancel_btn.width()-16, self.btn.y())
        self.cancel_btn.show()

        self.close_btn = QPushButton(self.widget)
        self.close_btn.setFocusPolicy(Qt.NoFocus)
        self.close_btn.resize(30, 30)
        self.close_btn.setStyleSheet(
            "QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
        self.close_btn.move(self.widget.width() - self.close_btn.width() - 4, 4)
        self.close_btn.setToolTip(_("close"))

        self.widget.setFixedSize(self.widget.width(), self.cancel_btn.y() + self.cancel_btn.height() +24)
        self.setFixedSize(self.widget.width() + 18 ,self.widget.height()+18)

        self.slot_show_dark_mode()

    def change_check_btn_statue(self,statue):
        if(hasattr(self,"check_btn3") == False):
            return
        if(statue == 2):
            self.check_btn3.setChecked(False)
            self.check_btn3.setEnabled(False)
            if(Globals.THEME_COLOR == 0):
                self.check_btn3.setStyleSheet("QCheckBox{border-radius: 3px;spacing: 0px;background: #ECECEC;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}")
            else:
                self.check_btn3.setStyleSheet("QCheckBox{border-radius: 3px;spacing: 0px;background: #3A3A3A;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}")
        else:
            self.check_btn3.setEnabled(True)
            if(Globals.THEME_COLOR == 0):
                self.check_btn3.setStyleSheet(
                    "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                    "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                    "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                    "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;}" \
                    "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            else:
                self.check_btn3.setStyleSheet(
                    "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                    "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                    "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                    "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;}" \
                    "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")

    #
    # 函数：处理主题颜色的显示
    #
    def slot_show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            if(Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            else:
                self.widget.setStyleSheet(".QWidget{border-radius:12px;background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #1B1B1B;font-weight: 500;background:transparent;}")
            self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
            self.line_label1.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
            self.line_label2.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
            self.auto_update_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            self.notice_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            self.auto_update_uksc_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            self.notice_software_update_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            self.auto_update_uksc_tip_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #999999;line-height: 20px;}")
            self.auto_update_software_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            self.auto_update_software_tip_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #999999;line-height: 20px;}")
            self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
            self.check_btn1.setStyleSheet(
                "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator{width: 16px;height: 16px;}" \
                "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            self.check_btn2.setStyleSheet(
                "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator{width: 16px;height: 16px;}" \
                "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            if(self.check_btn3.isEnabled() == True):
                self.check_btn3.setStyleSheet(
                    "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                    "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                    "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                    "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;}" \
                    "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            else:
                self.check_btn3.setStyleSheet(
                    "QCheckBox{border-radius: 3px;spacing: 0px;background: #ECECEC;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}")
        else:
            if (Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color:#3D3D41;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#1F2022;}")
            else:
                self.setStyleSheet("QFrame{background-color:#1F2022;}")
                self.widget.setStyleSheet(".QWidget{border-radius:12px;background-color:#3D3D41;border: 1px solid rgba(38, 38, 38, 0.15);}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #8F9399;font-weight: 500;background:transparent;}")
            self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #48484C;}")
            self.line_label1.setStyleSheet("QLabel{width: 424px;height: 1px;background: #48484C;}")
            self.line_label2.setStyleSheet("QLabel{width: 424px;height: 1px;background: #48484C;}")
            self.auto_update_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 20px;}")
            self.notice_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 20px;}")
            self.auto_update_uksc_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 20px;}")
            self.notice_software_update_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 20px;}")
            self.auto_update_uksc_tip_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #999999;line-height: 20px;}")
            self.auto_update_software_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 20px;}")
            self.auto_update_software_tip_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #999999;line-height: 20px;}")
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-close.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-close.png')}")
            self.check_btn1.setStyleSheet(
                "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator{width: 16px;height: 16px;}" \
                "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            self.check_btn2.setStyleSheet(
                "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                "QCheckBox::indicator{width: 16px;height: 16px;}" \
                "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            if(self.check_btn3.isEnabled() == True):
                self.check_btn3.setStyleSheet(
                    "QCheckBox{border-radius: 3px;spacing: 0px;background: transparent;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}" \
                    "QCheckBox:hover{background: transparent;border-radius: 3px;}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;border-radius:3px;}" \
                    "QCheckBox::indicator:unchecked{background-color:transparent;border:0px solid #bfbfbf;image: url(./res/set_check.png);}" \
                    "QCheckBox::indicator:unchecked:hover{background-color:transparent;border: 0px solid #8F9399;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator:unchecked:pressed{background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_hover.png);}" \
                    "QCheckBox::indicator{width: 16px;height: 16px;}" \
                    "QCheckBox::indicator:checked{border-radius: 3px;background-color: transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:hover{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}" \
                    "QCheckBox::indicator:checked:pressed{border-radius: 3px;background-color:transparent;border:0px solid #415FC4;image: url(./res/set_check_press.png);}")
            else:
                self.check_btn3.setStyleSheet("QCheckBox{border-radius: 3px;spacing: 0px;background: #3A3A3A;border-radius: 3px;border: 0px solid rgba(0, 0, 0, 0.15);}")

        # QApplication.processEvents()

    #
    # 函数：重绘函数
    #
    def set_paintEvent(self, event):
        painter = QPainter(self)
        m_defaultBackgroundColor = QColor(qRgba(0, 0, 0, 16))
        m_defaultBackgroundColor.setAlpha(50)
        path = QPainterPath()
        path.setFillRule(Qt.WindingFill)
        path.addRoundedRect(10, 10, self.width() - 20, self.height() - 20, 12, 12)

        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.fillPath(path, QBrush(QColor(m_defaultBackgroundColor.red(),
                                             m_defaultBackgroundColor.green(),
                                             m_defaultBackgroundColor.blue())))

        color = QColor(0, 0, 0, 16)
        i = 0
        while i < 4:
            path = QPainterPath()
            path.setFillRule(Qt.WindingFill)
            path.addRoundedRect(10 - i, 10 - i, self.width() - (10 - i) * 2, self.height() - (10 - i) * 2, 12, 12)
            color.setAlpha(int(100 - math.sqrt(i) * 50))
            painter.setPen(color)
            painter.drawPath(path)
            i = i + 1

        painter.setRenderHint(QPainter.Antialiasing)

    #
    # 函数：实现无标题栏窗口拖动
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.drag_pos = event.globalPos() - self.pos()
            event.accept()

    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        self.setWindowOpacity(1)

    # def mouseMoveEvent(self, event):
    #     if (self.mouse_press):
    #         self.move_pos = event.globalPos()
    #         self.move(self.move_pos - self.drag_pos)
    #         self.setWindowOpacity(1)
    #         event.accept()


#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     Wen Bo<wenbo@ubuntukylin.com>
#     Shine Huang<shenghuang@ubuntukylin.com>
# Maintainer:
#     Wen Bo<wenbo@ubuntukylin.com>
#     Shine Huang<shenghuang@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.


import os
import xdg.DesktopEntry
import time
from models.enums import Specials, PKG_NAME
from multiprocessing import process
from models.globals import Globals
import subprocess


def RemoveArgs(Execline):
    NewExecline = []
    for elem in Execline:
        elem = elem.replace("'","")
        elem = elem.replace("\"", "")
        if elem not in Specials:
            if (Globals.DEBUG_SWITCH):
                print(elem)
            NewExecline.append(elem)
    return NewExecline

# Actually execute the command

def Execute(cmd):
    if isinstance( cmd, str ) or isinstance( cmd, str):
        if (cmd.find("/home/") >= 0) or (cmd.find("su-to-root") >= 0) or (cmd.find("\"") >= 0):
            if (Globals.DEBUG_SWITCH):
                print("running manually...")
            try:
                return cmd
            except Exception as detail:
                if (Globals.DEBUG_SWITCH):
                    print(detail)
                return ""
    cmd = cmd.split()
    cmd = RemoveArgs(cmd)

    try:
        string = ' '.join(cmd)
        string = string
        #subprocess.Popen( cmd ) // use os.system instead of popen so children don't end up in zombie waiting for us to wait() for them
        # os.system(string)
        return string
    except Exception as detail:
        if (Globals.DEBUG_SWITCH):
            print("error:",detail)
        return ""

#
# 函数：获取软件运行命令
#
def get_run_command(pkgname):
    # 对一些特殊软件单独处理


    fullcmd = ""

    desktopfile = "/usr/share/applications/" + pkgname + ".desktop"
    desktopfile1 = "/usr/share/applications/kde4/" + pkgname + ".desktop"
    #print("555555",desktopfile)

    if os.path.exists(desktopfile):
        DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile)
        fullcmd = DeskTopEntry.getExec()
    elif os.path.exists(desktopfile1):
        DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile1)
        fullcmd = DeskTopEntry.getExec()
    else:
        if pkgname in Globals.PKG_NAME:
            pkgname = Globals.PKG_NAME[pkgname]

        desktopfile = "/usr/share/applications/" + pkgname + ".desktop"
        # print("555555",desktopfile)

        if os.path.exists(desktopfile):
            DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile)
            fullcmd = DeskTopEntry.getExec()
        else:
            desktopfile = "/usr/share/applications/kde4/" + pkgname + ".desktop"
            if(os.path.exists(desktopfile)):
                DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile)
                fullcmd = DeskTopEntry.getExec()
    if fullcmd == "":
        user_desktop_path = os.path.join(os.path.expanduser("~"), ".local", "share", "applications")
        if(os.path.exists(user_desktop_path) == False):
            user_desktop_path = os.path.join(os.path.expanduser("~"), '桌面')

        desktopfile = user_desktop_path + "/" + pkgname + ".desktop"

        if os.path.exists(desktopfile):
            time.sleep(0.5)
            DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile)
            fullcmd = DeskTopEntry.getExec()

    # command = ['']
    # # 截取运行指令部分
    # if exc:
    #     command = re.findall('Exec=(.*)',exc)
    # print command,"000000000000000000000"
    # # 有些软件Exec后面会有%U %f等，进行过滤
    # if re.findall(' ',command[0]):
    #     command = re.findaqll('(.*) ',command[0])
    #     print command,"111111111111111111111111"
    # #split the command to prevent the error: "OSError: [Errno 2] 没有那个文件或目录"
    # fullcmd = command[0]
    # print fullcmd,"2222222222222222222"
    # if fullcmd:
    #     fullcmd = command[0].split()
    return fullcmd

def run_app(pkgname):
    cmd = get_run_command(pkgname)
    if cmd != "":
        if (Globals.DEBUG_SWITCH):
            print(("\n#####run_app:",cmd))
    cmd = Execute(cmd)
    # #p = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
    # os.system(cmd[0] + "&")#fixed bug 1402953
    return cmd

def run_appa():
    p = subprocess.Popen(["eog", "/home/shine/Downloads/009-01.png"], stdin = subprocess.PIPE, stdout = subprocess.PIPE, stderr = subprocess.PIPE, shell = False)


def judge_app_run_or_not(pkgname):
    result = 0
    cmd = get_run_command(pkgname)
    if cmd[0] is not None:
        cmd = 'pgrep -f ' + cmd[0] + ' | wc -l'
        ps = os.popen(cmd)
        result = int(ps.read().replace('/n', ''))
        ps.close()
    return result

def main():
    run_appa()

if __name__ == '__main__':
    main()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from PyQt5 import QtCore, QtGui
from ui.starwidget import StarWidget
from ui.messagebox import MessageBox
from models.enums import Signals
# from ui.loadingdiv import *
import sip
import math
import gettext
gettext.bindtextdomain("ubuntu-kylin-software-center", "/usr/share/locale")
gettext.textdomain("ubuntu-kylin-software-center")
_ = gettext.gettext
from models.application import *
from models.enums import UBUNTUKYLIN_DATA_PATH
from models.enums import setLongTextToElideFormat
import datetime
# from models.enums import CACHE_DIR,BUTTON_PRESSED,BUTTON_ENTER,BUTTON_LEAVE,BUTTON_DISABLE,AppMsg
#


class All_Review_Widget(QWidget,Signals):
    ad_move_left_time = QTimer()
    ad_move_right_time = QTimer()
    final_x_position = 0
    x = 0
    maxpage = ''
    mainwindow = ''
    debfile = ''
    sshotcount = 0
    bigsshot = ''
    reviewpage = ''
    currentreviewready = ''
    debfile = None
    Row_er = 0
    Expand_height = 0
    is_clean_star = 0
    add_revieheight = 0
    Line_height = 0
    text_lidit = ""
    dest_str = ""
    SET_ISNTALL = False
    count = 0
    i = 1
    reviewlist1=[]
    alist = []
    commend_height = 260

    set_show_review_height = pyqtSignal(int)
    def __init__(self,reviewlist1,app_detail,parent=None):
        QWidget.__init__(self,parent)
        self.dblist = []
        self.m = 0
        # self.app = app
        # self.reviewpage = reviewpage
        self.ratings_average = 0
        # self.messageBox = MessageBox(self)
        self.mainwindow = parent
        self.app_detail = app_detail
        self.mouse_press = False
        # self.setFixedSize(1340,278)

        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        #

        self.widget = QWidget(self.mainwindow)
        self.widget.resize(self.app_detail.editorial_comments_widget.width(), self.commend_height)
        self.widget.move(0, 0)
        self.widget.setStyleSheet("QWidget{border-radius:12px;background-color:transparent;}")
        self.review_card_width = int((self.widget.width() - 20) / 2)

        # self.review_widget1 = QWidget(self.widget)
        # self.review_widget1.setFixedWidth(self.widget.width())
        # self.review_widget1.setStyleSheet("QWidget{border:1px ;border-radius:12px;background:transparent;}")
        # self.review_widget1.move(0, 0)


        self.total_review_count = len(reviewlist1)
        self.show_review_count = 0
        self.right_click_count = 0

        self.show_review_x = 0
        self.show_review_y = 0

        self.reviewlist1 = reviewlist1

        self.innit_ui(self.reviewlist1)

    def innit_ui(self,reviewlist1):

        # ratings_average=3
        reviewlist = reviewlist1
        if len(reviewlist) <= 10:
            if len(reviewlist) % 2 == 0:
                self.widget.resize(self.widget.width(), self.commend_height * (len(reviewlist) / 2) + 20 * (len(reviewlist) / 2 ))
                # self.review_widget1.resize(self.review_widget1.width(),self.commend_height * (len(reviewlist)/2) + 20 * (len(reviewlist)/2 ))

            else:
                self.widget.resize(self.widget.width(),self.commend_height * ((len(reviewlist)+1)/2) + 20 * ((len(reviewlist)+1)/2 ))
                # self.review_widget1.resize(self.review_widget1.width(),self.commend_height * ((len(reviewlist)+1)/2) + 20 * ((len(reviewlist)+1)/2 ))
        else:
            self.widget.resize(self.widget.width(), self.commend_height * 5 + 20 * (5 ))
            # self.review_widget1.resize(self.review_widget1.width(),self.commend_height * 5 + 20 * (5 ))


        for k in range(self.total_review_count):
            if k % 2 == 0:
                ratings_average = self.reviewlist1[k].user_rating
                self.review1 = ReviewLabel(ratings_average, self.review_card_width, reviewlist[k],self.app_detail, self.widget)
                self.review1.move(0,self.review1.height() * k/2 + 20 * k/2)
                # self.review1.move(0, 100)
                self.review1.raise_()
                self.review1.show()
            else:
                ratings_average = self.reviewlist1[k].user_rating
                self.review1 = ReviewLabel(ratings_average,self.review_card_width, reviewlist[k], self.app_detail,self.widget)
                self.review1.move(self.review_card_width+20, self.review1.height() * (k-1)/2 + 20 * (k-1)/2)
                self.review1.raise_()
                self.review1.show()


        self.show_review_count = 10
        self.show_review_y = self.review1.height() * 5 + 20 * 5
        self.count = len(reviewlist)

    def re_move(self):
        self.widget.resize(self.app_detail.editorial_comments_widget.width(), self.widget.height())
        self.widget.move(0, 0)
        self.review_card_width = int((self.widget.width() - 20) / 2)
        reviews = self.widget.children()
        # self.widget.setFixedSize(self.widget.width(), self.widget.height())
        # self.review_widget1.move(0,0)
        n = 0
        for i in reviews:
            i.setFixedSize(self.review_card_width, self.commend_height)
            i.ReviewWidget.resize(self.review_card_width, self.commend_height)
            i.re_move()
            if(n % 2 == 1):
                i.move(self.review_card_width  + 20, (int(n/2))*20+int(n/2)*i.height())
            else:
                i.move(0, (int(n/2))*20+int(n/2)*i.height())
            n = n + 1


    #函数：加载更多评论---在app_detail_widget调用，使滑动条到底时自动加载更多评论
    def get_review(self,reviewlist):
        self.m += 1
        self.reviewlist1 = reviewlist
        self.total_review_count = len(self.reviewlist1)
        # 没有更多评论啦~
        if self.show_review_count >= self.total_review_count:
            return
        # 更多评论不够10条
        elif self.show_review_count + 10 > self.total_review_count:
            num = self.total_review_count - self.show_review_count
            # 扩大widget的大小
            if num % 2 == 0:
                self.set_show_review_height.emit(num / 2 * self.commend_height + (num / 2) * 20)
                self.mainwindow.resize(self.mainwindow.width(),self.mainwindow.height() + num / 2 * self.commend_height + (num / 2) * 20)
                self.widget.resize(self.widget.width(), self.commend_height * ((self.show_review_count + num) / 2) + 20 * ((self.show_review_count + num) / 2))
                # self.review_widget1.resize(self.review_widget1.width(), self.commend_height * ((self.show_review_count + num) / 2) + 20 * (
                #             (self.show_review_count + num) / 2))
            else:
                self.set_show_review_height.emit((num + 1) / 2 * self.commend_height + ((num + 1) / 2) * 20)
                self.mainwindow.resize(self.mainwindow.width(),
                                       self.mainwindow.height() + (num + 1) / 2 * self.commend_height + ((num + 1) / 2) * 20)
                self.widget.resize(self.widget.width(), self.commend_height * (((self.show_review_count + num) + 1) / 2) + 20 * (
                            ((self.show_review_count + num) + 1) / 2))
                # self.review_widget1.resize(self.review_widget1.width(), self.commend_height * (((self.show_review_count + num) + 1) / 2) + 20 * (
                #             ((self.show_review_count + num) + 1) / 2))
            # 排列每一个评论的小widget
            for k in range(num):
                if k % 2 == 0:

                    self.ratings_average = self.reviewlist1[self.show_review_count + k].user_rating
                    self.review1 = ReviewLabel(self.ratings_average, self.review_card_width,self.reviewlist1[self.show_review_count + k],
                                               self.app_detail,self.widget)
                    self.review1.move(0, self.show_review_y + self.review1.height() * k / 2 + 20 * k / 2)
                    self.review1.raise_()
                    self.review1.show()
                else:
                    self.ratings_average = self.reviewlist1[self.show_review_count + k].user_rating
                    self.review1 = ReviewLabel(self.ratings_average, self.review_card_width,self.reviewlist1[self.show_review_count + k],
                                               self.app_detail,self.widget)
                    self.review1.move(self.review_card_width + 20, self.show_review_y + self.review1.height() * (k - 1) / 2 + 20 * (k - 1) / 2)
                    self.review1.raise_()
                    self.review1.show()
            self.show_review_count += num
            if num % 2 == 0:
                self.show_review_y += self.review1.height() * num / 2 + 20 * num / 2
            else:
                self.show_review_y += self.review1.height() * (num + 1) / 2 + 20 * (num + 1) / 2
        # 还能加载10条评论
        else:
            num = 10
            self.mainwindow.resize(self.mainwindow.width(), self.mainwindow.height() + 5 * self.commend_height + 5 * 20)
            self.set_show_review_height.emit(5 * self.commend_height + 5 * 20)
            # 扩大widget的大小
            self.widget.resize(self.widget.width(), self.commend_height * ((self.show_review_count + self.i * 10) / 2) + 20 * (
                        (self.show_review_count + self.i * 10) / 2))
            # self.review_widget1.setFixedSize(self.review_widget1.width(), self.commend_height * ((self.show_review_count + self.i * 10) / 2) + 20 * (
            #             (self.show_review_count + self.i * 10) / 2))
            self.i = self.i + 1
            for k in range(num):
                if k % 2 == 0:
                    self.ratings_average = self.reviewlist1[self.show_review_count + k].user_rating
                    self.review1 = ReviewLabel(self.ratings_average, self.review_card_width,self.reviewlist1[self.show_review_count + k],
                                               self.app_detail,self.widget)
                    self.review1.move(0, self.show_review_y + self.review1.height() * k / 2 + 20 * k / 2)
                    self.review1.raise_()
                    self.review1.show()
                else:
                    self.ratings_average = self.reviewlist1[self.show_review_count + k].user_rating
                    self.review1 = ReviewLabel(self.ratings_average, self.review_card_width,self.reviewlist1[self.show_review_count + k],
                                               self.app_detail,self.widget)
                    self.review1.move(self.review_card_width + 20, self.show_review_y + self.review1.height() * (k - 1) / 2 + 20 * (k - 1) / 2)
                    self.review1.raise_()
                    self.review1.show()

            self.show_review_count += num
            if num % 2 == 0:
                self.show_review_y += self.review1.height() * num / 2 + 20 * num / 2
            else:
                self.show_review_y += self.review1.height() * (num + 1) / 2 + 20 * (num + 1) / 2

        Globals.IS_GETTING_REVIEW = False


    #
    # 函数：实现无标题栏窗口拖动
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.drag_pos = event.globalPos() - self.pos()
            event.accept()

    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        self.setWindowOpacity(1)

    def mouseMoveEvent(self, event):
        if (self.mouse_press):
            self.move_pos = event.globalPos()
            self.move(self.move_pos - self.drag_pos)
            self.setWindowOpacity(1)
            event.accept()

class ReviewLabel(QWidget):

    commend_height = 260
    agree_with = False
    disagree = False

    def __init__(self, ratings_average,width, reviewlist,app_detail, parent=None):
        QWidget.__init__(self,parent)
        # strstr = ""
        # k = 0
        self.m_parent = parent
        self.app_detail = app_detail
        self.reviewlist = reviewlist
        self.comment_line_num = 6
        self.ReviewWidget = QWidget(self)
        self.ReviewWidget.resize(width,self.commend_height)
        self.ReviewWidget.move(0,0)
        # self.ReviewWidget.setStyleSheet("QWidget{border:none;border-radius:12px;background-color:#F4F4F4}")
        Globals.ADD_WIDGET.append(self.ReviewWidget)
        self.userHead = QLabel(self.ReviewWidget)
        self.userHead.setGeometry(QtCore.QRect(16, 16, 40, 40))
        self.userHead.setAttribute(Qt.WA_TranslucentBackground)
        self.userName = QLabel(self.ReviewWidget)
        self.userName.setGeometry(QtCore.QRect(66, 16, 166, 22))
        self.userName.setAttribute(Qt.WA_TranslucentBackground)
        # self.userName.setAttribute(Qt.WA_TranslucentBackground)
        self.me_label = QLabel(self.ReviewWidget)
        self.me_label.resize(20, 18)
        # self.me_label.setAttribute(Qt.WA_TranslucentBackground)
        self.me_label.move(self.userName.x() + self.userName.width() + 8,
                           int((self.userName.height() - self.me_label.height()) / 2))
        if (Globals.LAN == "zh_CN"):
            self.me_label.setStyleSheet("QLabel{background-image:url('res/myself_zh.png')}")
        else:
            self.me_label.setStyleSheet("QLabel{background-image:url('res/myself_en.png')}")
        self.comment = QLabel(self.ReviewWidget)
        self.comment.setAttribute(Qt.WA_TranslucentBackground)
        self.comment.setContextMenuPolicy(Qt.NoContextMenu)
        self.createDate = QLabel(self.ReviewWidget)
        self.createDate.setAttribute(Qt.WA_TranslucentBackground)
        self.createDate.move(self.width() - 16 - len(self.createDate.text() * 7), 16)
        #self.createDate.setGeometry(QtCore.QRect(345, 16, 155, 20))

        self.star = StarWidget('small', ratings_average, self.ReviewWidget)
        self.star.move(67, 43)
        self.star.setFixedSize(98,14)
        self.star.setStyleSheet("QWidget{background-color:transparent;}")
        self.setFixedSize(width,self.commend_height)
        self.star.hide()

        self.agree_with_btn = QPushButton(self.ReviewWidget)
        self.agree_with_btn.setFocusPolicy(Qt.NoFocus)
        # self.agree_with_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.agree_with_btn.resize(20,20)
        self.agree_with_btn.setStyleSheet("QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image:url('res/default_agree.png');}QPushButton:hover{background-image: url(./res/hover_agree.png);}QPushButton:pressed{background-image: url(./res/press_agree.png);}")
        self.agree_with_btn.move(16,self.ReviewWidget.height()-self.agree_with_btn.height()-16)
        self.agree_with_btn.clicked.connect(lambda: self.app_detail.slot_click_agree_with_btn(self.reviewlist,self))

        self.agree_with_count_label = QLabel(self.ReviewWidget)
        self.agree_with_count_label.setAttribute(Qt.WA_TranslucentBackground)
        self.agree_with_count_label.resize(20, 20)
        self.agree_with_count_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;}")
        self.agree_with_count_label.move(self.agree_with_btn.x()+self.agree_with_btn.width()+4,self.agree_with_btn.y()+int((self.agree_with_btn.height()-self.agree_with_count_label.height())/2))

        self.disagree_btn = QPushButton(self.ReviewWidget)
        self.disagree_btn.setFocusPolicy(Qt.NoFocus)
        # self.agree_with_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.disagree_btn.resize(20, 20)
        self.disagree_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image:url('res/default_disagree.png');}QPushButton:hover{background-image: url(./res/hover_disagree.png);}QPushButton:pressed{background-image: url(./res/press_disagree.png);}")
        self.disagree_btn.move(79, self.ReviewWidget.height() - self.agree_with_btn.height() - 16)
        self.disagree_btn.clicked.connect(lambda: self.app_detail.slot_click_disagree_btn(self.reviewlist,self))

        self.disagree_count_label = QLabel(self.ReviewWidget)
        self.disagree_count_label.setAttribute(Qt.WA_TranslucentBackground)
        self.disagree_count_label.resize(20, 20)
        self.disagree_count_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;}")
        self.disagree_count_label.move(self.disagree_btn.x() + self.disagree_btn.width() + 4,
                                         self.disagree_btn.y() + int(
                                             (self.disagree_btn.height() - self.disagree_count_label.height()) / 2))

        self.delete_btn = QPushButton(self.ReviewWidget)
        self.delete_btn.setFocusPolicy(Qt.NoFocus)
        self.delete_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.delete_btn.setStyleSheet("QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;}")
        self.delete_btn.setText(_("Delete"))
        self.delete_btn.adjustSize()
        self.delete_btn.move(self.ReviewWidget.width() - 16 - self.delete_btn.width(),
                             self.ReviewWidget.height() - self.delete_btn.height() - 16)
        self.delete_btn.clicked.connect(lambda: self.app_detail.slot_delete_comment(self.reviewlist,self.app_detail.app_msg.pkgname))


        self.comment.setAlignment(Qt.AlignVCenter)
        self.comment.setWordWrap(True)
        self.comment.setAlignment(Qt.AlignTop)
        self.comment.setTextInteractionFlags(Qt.TextSelectableByMouse)
        self.userName.setStyleSheet("QLabel{font-size: 16px;font-weight: 500;color: #303133;line-height: 22px;}")
        Globals.ADD_WIDGET_USERNAME.append(self.userName)
        self.comment.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 21px;}")
        Globals.ADD_WIDGET_COMMENT.append(self.comment)
        if(reviewlist.user_profile != ''):
            if (reviewlist.user_display == Globals.LOGIN_ACCOUNT and Globals.LOGIN_SUCCESS):
                user_profile = UBUNTUKYLIN_DATA_PATH + "user_profile/" + Globals.USER_PROFILE
            else:
                user_profile = UBUNTUKYLIN_DATA_PATH + "user_profile/" + reviewlist.user_profile
            pix2 = QPixmap(user_profile)
            fitpixmap_userIcon = pix2.scaled(40, 40, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
            fitpixmap_userIcon = self.PixmapToRound(fitpixmap_userIcon, 40,40)
            self.userHead.setPixmap(fitpixmap_userIcon)
        else:
            self.userHead.setStyleSheet("QLabel{background-image:url('res/userhead.png')}")
        if(reviewlist.like_count != None):
            self.comment.setGeometry(QtCore.QRect(16, 66, int(self.ReviewWidget.width()-16*2), int(self.delete_btn.y()-self.comment.y()-10)))
            self.agree_with_count_label.setText(str(reviewlist.like_count))
            self.agree_with_count_label.adjustSize()
            self.disagree_count_label.setText(str(reviewlist.unlike_count))
            self.disagree_count_label.adjustSize()
            self.comment_line_num = 6
        else:
            self.comment.setGeometry(QtCore.QRect(16, 66, self.ReviewWidget.width() - 16*2, 150))
            self.agree_with_count_label.hide()
            self.agree_with_btn.hide()
            self.disagree_count_label.hide()
            self.disagree_btn.hide()
            self.comment_line_num = 7


        # SHA_TZ = datetime.timezone(
        #     datetime.timedelta(hours=8),
        #     name='Asia/Shanghai',
        # )
        # # 协调世界时
        # utc_now = datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc)
        # beijing_now = utc_now.astimezone(SHA_TZ).strftime("%Y-%m-%d %H:%M:%S")
        # format_pattern = "%Y-%m-%d %H:%M:%S"
        # difference = (datetime.datetime.strptime(str(beijing_now), format_pattern) - datetime.datetime.strptime(
        #     reviewlist.date, format_pattern))
        # print(difference)

        self.createDate.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;}")
        # Globals.ADD_WIDGET_DATE.append(self.createDate)

        self.userName.setText(reviewlist.user_display)
        self.userName.adjustSize()
        self.me_label.move(self.userName.x() + self.userName.width() + 8,
                           self.userName.y()+int((self.userName.height() - self.me_label.height()) / 2))
        # if(str(reviewlist.user_id) == str(Globals.USER_ID)):
        if(str(reviewlist.account) == str(Globals.ACCOUNT)):
            self.me_label.show()
            self.delete_btn.show()
        else:
            self.me_label.hide()
            self.delete_btn.hide()
        self.createDate.setText(reviewlist.date)
        self.comment.setText(reviewlist.content)
        self.setLongTextToElideFormat(self.comment, reviewlist.content,self.comment_line_num)
        self.createDate.move(width-16-len(self.createDate.text()*7),16)
        self.createDate.setFixedHeight(20)
        if(reviewlist.property != None and str(reviewlist.property) == "1" ):
            self.agree_with = True
            self.click_agree_over()
        elif(reviewlist.property != None and str(reviewlist.property) == "2" ):
            self.disagree = True
            self.click_disagree_over()

        self.show_dark_mode()

    def check_account(self):
        if (str(self.reviewlist.account) == str(Globals.ACCOUNT)):
            self.me_label.show()
            self.delete_btn.show()
        else:
            self.me_label.hide()
            self.delete_btn.hide()

    def click_disagree_over(self):
        self.agree_with_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image:url('res/default_agree.png');}QPushButton:hover{background-image: url(./res/hover_agree.png);}QPushButton:pressed{background-image: url(./res/press_agree.png);}")
        self.disagree_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image: url(./res/press_disagree.png);}")

    def click_agree_over(self):
        self.agree_with_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image: url(./res/press_agree.png);}")
        self.disagree_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image:url('res/default_disagree.png');}QPushButton:hover{background-image: url(./res/hover_disagree.png);}QPushButton:pressed{background-image: url(./res/press_disagree.png);}")

    def init_btn_statue(self):
        self.agree_with_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image:url('res/default_agree.png');}QPushButton:hover{background-image: url(./res/hover_agree.png);}QPushButton:pressed{background-image: url(./res/press_agree.png);}")
        self.disagree_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;background-image:url('res/default_disagree.png');}QPushButton:hover{background-image: url(./res/hover_disagree.png);}QPushButton:pressed{background-image: url(./res/press_disagree.png);}")


    def re_move(self):
        self.comment.setGeometry(QtCore.QRect(16, 66, self.ReviewWidget.width() - 16*2, self.comment.height()))
        print("big", self.comment.height())
        self.createDate.move(self.width() - 16 - len(self.createDate.text() * 7), 16)
        self.createDate.setFixedHeight(20)
        self.setLongTextToElideFormat(self.comment, self.reviewlist.content,self.comment_line_num)
        self.delete_btn.move(self.ReviewWidget.width() - 16 - self.delete_btn.width(),
                             self.ReviewWidget.height() - self.delete_btn.height() - 16)

    def show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            self.setStyleSheet(".QWidget{border:none;border-radius:12px;background-color:#F4F4F4}")
            self.ReviewWidget.setStyleSheet(".QWidget{border:none;border-radius:12px;background-color:#F4F4F4}")
            self.userName.setStyleSheet("QLabel{font-size: 16px;font-weight: 500;color: #303133;line-height: 22px;}")
            self.comment.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 21px;}")
        else:
            self.setStyleSheet(".QWidget{border:none;border-radius:12px;background-color:#393939}")
            self.ReviewWidget.setStyleSheet(".QWidget{border:none;border-radius:12px;background-color:#393939}")
            self.userName.setStyleSheet("QLabel{font-size: 16px;font-weight: 500;color: #F9F9F9;line-height: 22px;}")
            self.comment.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 21px;}")


    def setLongTextToElideFormat(self, label, te,line_num=7):

        te = te.replace("\n", ",").replace("\r", "").replace("\t", "").replace(";","；").replace(",","，")
        metrics = QFontMetrics(label.font())
        elidedText = metrics.elidedText(te, Qt.ElideRight, label.width()*line_num)
        label.setText(elidedText)
        if ("…" in elidedText):

            count = 0
            set_text = ""
            for i in te:
                if(count < 35):
                    set_text = set_text + i
                elif(count == 35):
                    set_text = set_text + i + "\n"
                    count = 0
                count = count +1
            QToolTip.setFont(QFont("SansSerif", 10))
            self.setToolTip(set_text)
        else:
            self.splitText(label, te, label.width())


    #label:控件，text：文字，nlabelsize：控件宽
    def splitText(self,label,text,nlabelsize):
        font = QFont()
        font.setPixelSize(14)
        m_font = QFontMetrics(font)
        nTextSize = m_font.width(text)
        text = label.text()
        label.setText("")
        split_num = 1
        if (label.width() % 2 != 0):
            width = label.width() - 1
        else:
            width = label.width()
        for i in text:
            pre_text = label.text()
            label.setText(label.text() + i)
            s = m_font.boundingRect(label.text()).size().width()
            if (s <= width * split_num+split_num-1):
                pass
            else:
                label.setText(pre_text + "\n" + i)
                split_num = split_num + 1


    #将图片切割成圆角
    def PixmapToRound(self,src,x,y):
        pixmapa = QPixmap(src)
        pixmap = QPixmap(x, y)
        pixmap.fill(Qt.transparent)
        painter = QPainter(pixmap)
        painter.setRenderHint(QPainter.Antialiasing, True)
        # painter.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
        path = QPainterPath()
        rect = QRectF(0,0,x,y)
        path.addRoundedRect(rect, 20.0, 20.0)
        painter.setClipPath(path)
        painter.drawPixmap(0, 0, x, y, pixmapa)

        return pixmap



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
import math
from models.globals import Globals
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Login_serch(QFrame):
    def __init__(self,w,parent = None):
        QFrame.__init__(self,parent)
        self.w = w
        self.init_ui()
        self.paintEvent = self.set_paintevent

    def init_ui(self):
        self.resize(self.w+20,0)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        # self.setFrameShape(QFrame.NoFrame)
        # self.setStyleSheet("QFrame{background:red;}")
        self.widget = QWidget(self)
        # self.widget.setStyleSheet("QWidget{background: #FFFFFF;border-radius: 4px;}")
        self.widget.resize(self.w,0)
        self.widget.move(10,10)
        #self.setAttribute(Qt.WA_TranslucentBackground)

        self.item_list_widget = QListWidget(self.widget)
        self.item_list_widget.resize(self.w-8,0)
        self.item_list_widget.move(4,2)
        # self.item_list_widget.setStyleSheet("QListWidget{background-color:#ffffff;border:0px solid #cfcfcf;border-radius: 4px;}QListWidget::item{height: 30px;border-radius: 2px;background:#FFFFFF;}QListWidget::item:hover{background:#F7F7F7;}QListWidget::item:selected{background:#F7F7F7;}")
        self.slot_show_dark_mode()

    def slot_show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            # self.setStyleSheet("QFrame{background: transparent;}")
            if(Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background: #FFFFFF;}")
            else:
                self.widget.setStyleSheet(".QWidget{background: #FFFFFF;border-radius: 4px;}")
            self.item_list_widget.setStyleSheet(
                "QListWidget{background-color:#ffffff;border:0px solid #cfcfcf;border-radius: 4px;}QListWidget::item{height: 30px;border-radius: 2px;background:#FFFFFF;}QListWidget::item:hover{background:#296CD9;}")
        else:
            # self.setStyleSheet("QFrame{background:red;}")
            if(Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color: #3D3D41;border-radius: 4px;}")
            else:
                self.widget.setStyleSheet(".QWidget{background-color: #3D3D41;border-radius: 4px;}")
            self.item_list_widget.setStyleSheet("QListWidget{background-color:#3D3D41;border:0px solid #cfcfcf;border-radius: 4px;}QListWidget::item{height: 30px;border-radius: 2px;background:#3D3D41;}QListWidget::item:hover{background:#296CD9;}")
        for i in range(self.item_list_widget.count()):
            item = self.item_list_widget.item(i)
            get_widget = self.item_list_widget.itemWidget(item)
            get_widget.slot_show_dark_mode()
        # QApplication.processEvents()

    def set_paintevent(self,event):
        painter = QPainter(self)
        m_defaultBackgroundColor = QColor(qRgb(255, 255, 255))
        m_defaultBackgroundColor.setAlpha(50)
        path = QPainterPath()
        path.setFillRule(Qt.WindingFill)
        path.addRoundedRect(10, 10, self.width() - 20, self.height() - 20, 4, 4)

        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.fillPath(path, QBrush(QColor(m_defaultBackgroundColor.red(),
                                             m_defaultBackgroundColor.green(),
                                             m_defaultBackgroundColor.blue())))

        color = QColor(0, 0, 0, 20)
        i = 0
        while i < 4:
            path = QPainterPath()
            path.setFillRule(Qt.WindingFill)
            path.addRoundedRect(10 - i, 10 - i, self.width() - (10 - i) * 2, self.height() - (10 - i) * 2, 4, 4)
            color.setAlpha(int(100 - math.sqrt(i) * 50))
            painter.setPen(color)
            painter.drawPath(path)
            i = i + 1

        painter.setRenderHint(QPainter.Antialiasing)


class line_widget(QWidget):
    def __init__(self,w,parent = None):
        QWidget.__init__(self,parent)
        self.w = w
        self.init_ui()

    def init_ui(self):
        self.resize(self.w,30)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setStyleSheet("QWidget{background-color:transparent;border-radius:2px;}")

        self.username_label = QLabel(self)

        # self.username_label.setAttribute(Qt.WA_TranslucentBackground)
        self.username_label.setFixedHeight(30)
        self.username_label.move(20, 0)
        self.username_label.setAttribute(Qt.WA_TranslucentBackground)
        self.username_label.setAlignment(Qt.AlignVCenter)
        self.username_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;}")
        # self.username_label.move(9, int((self.height() - self.username_label.height())/ 2))

        self.pwd_label = QLabel(self)
        # self.pwd_label.setAttribute(Qt.WA_TranslucentBackground)
        self.pwd_label.setStyleSheet("QLabel{background-color:transparent;}")
        self.pwd_label.hide()

        self.state_label = QLabel(self)
        # self.state_label.setAttribute(Qt.WA_TranslucentBackground)
        self.state_label.setStyleSheet("QLabel{background-color:transparent;}")
        self.state_label.hide()
        self.slot_show_dark_mode()

    def slot_show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            self.username_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;}")
        else:
            self.username_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;}")
        # QApplication.processEvents()

    def enterEvent(self, event):
        self.username_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #ffffff;}")

    def leaveEvent(self,event):
        if (Globals.THEME_COLOR == 0):
            self.username_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;}")
        else:
            self.username_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;}")



#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     Shine Huang<shenghuang@ubuntukylin.com>
#     maclin <majun@ubuntukylin.com>
# Maintainer:
#     Shine Huang<shenghuang@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE

import sys,os

import apt
from utils import run
from models.enums import PkgStates,UBUNTUKYLIN_RES_ICON_PATH,SCREENSHOT_THUMB_URL,SCREENSHOT_LARGE_URL,UBUNTUKYLIN_RES_SCREENSHOT_PATH
from models.globals import Globals
from utils.log_manager import LogManager
import gettext
gettext.textdomain("kylin-software-center")
_ = gettext.gettext


class BaseInfo:

    def __init__(self, pkg_name):
        self.pkgname = pkg_name

class Application(BaseInfo):

    # work type
    mark = ''

    def __init__(self,id, pkgname, displayname_cn, category_name,category_name_cn, apt_cache,is_notice = False):
        super().__init__(pkgname)
        if(is_notice == False):
            if not pkgname:
                print("error",pkgname,displayname_cn,category_name,category_name_cn)
                raise ValueError("Need either appname or pkgname or request")
        # self.init_status = "nothing"
        self.is_notice = is_notice
        self.app_id = id
        self.pkgname = pkgname
        self.displayname_cn = displayname_cn
        self.category_name = category_name
        self.category_name_cn = category_name_cn
        self.from_ukscdb = True
        if not apt_cache:
            self.package = None
        else:
            try:
                self.package = apt_cache[pkgname]
                self.summary_init = self.package.candidate.summary
                self.description_init = self.package.candidate.description
            except:
                self.package = None
        self.cache = apt_cache
        self.thumbnail_url = None
        self.screenshot_url = None
        self.thumbnailfile = UBUNTUKYLIN_RES_SCREENSHOT_PATH+ pkgname + "_thumbnail.png"
        self.screenshotfile = UBUNTUKYLIN_RES_SCREENSHOT_PATH + pkgname + "_screenshot.png"
        self.iconfile = UBUNTUKYLIN_RES_ICON_PATH + pkgname + ".png"
        self.screenshots = []
        self.screenshots_url = ""
        self.screenshots_updatetime = ""
        self.icons = []
        self.reviews = {}
        self.reivewpage = 0
        self.rnrStat = None
        self.ratings_average = 0
        self.ratings_total = 0
        self.review_total = 0

        self.downloadrank = 32767
        self.ratingrank = 32767
        self.pointoutrank = 32767
        self.recommendrank = 32767
        self.downloadcount = 0
        self.arch = None
        self.system_name = None
        self.cpu_model = None
        self.no_cpu_model = None
        self.depends = None


        self.has_desktop = False
        self.install_date = ''  # the date first install this app, get from server

        self.status = PkgStates.NOTHING

        self.percent = 0
        self.icon_path = ""
        self.down_cover_image_path = ""
        self.down_preview_image_path = ""
        self.is_removed = False
        self.initialsName = ""
        self.pinyinName = ""
        self.anotherName = ""
        self.certSubjectOu = ""
        self.softStyle = 1
        self.website = None
        self.manufacturers =""
        self.init_screen_shot = False
        self.popularity = None

    # app work status this moment: installing, updating ...
    # @property
    # def status(self):
    #     return PkgStates.NOTHING

    @property
    def name(self):
        return self.pkgname

    @property
    def thumbnail(self):
        self.thumbnail_url = SCREENSHOT_THUMB_URL % {
            'pkgname': self.pkgname,
            'version': self.version or 0,
        }

        return self.thumbnail_url

    @property
    def screenshot(self):
        self.screenshot_url = SCREENSHOT_LARGE_URL % {
            'pkgname': self.pkgname,
            'version': self.version or 0,
        }

        return self.screenshot_url

    @property
    def description(self):
        return self.description_init

    @description.setter
    def description(self,description_set):
        self.description_init = description_set

    @property
    def summary(self):
       return self.summary_init

    @summary.setter
    def summary(self,summary_set):
        self.summary_init = summary_set

    @property
    def packageSize(self):
        try:
            return self.package.candidate.size
        except:
            return 0

    @property
    def installedSize(self):
        try:
            return self.package.candidate.installed_size
        except:
            return 0

    @property
    def version(self):
        try:
            return self.package.candidate.version
        except:
            return " "

    @property
    def pkg_status(self):
        if(self.is_installed == False):
            return PkgStates.UNINSTALLED
        else:
            if(self.is_upgradable == False):
                return PkgStates.INSTALLED
            else:
                return PkgStates.UPGRADABLE

    @property
    def is_installed(self):
        return self.package.is_installed

    @property
    def is_upgradable(self):
        return self.package.is_upgradable

    @property
    def installed_version(self):
        if(self.package.installed is not None):
            return self.package.installed.version
        else:
            return " "

    @property
    def candidate_version(self):
        try:
            return self.package.candidate.version
        except:
            return " "

    @property
    def is_runnable(self):
        if(run.get_run_command(self.name) != ""):
            return True
        else:
            return False

    def run(self):
        run.run_app(self.name)
        # pro_times = run.judge_app_run_or_not(self.name)
        # if pro_times == 0 or pro_times == 1:
        #     run.run_app(self.name)
        # else:
        #     print self.name + "已经运行"

    # get total download size include dependencies
    def get_total_size(self):
        totalsize = 0
        deplist = self.package.candidate.dependencies
        for dep_l in deplist:
            dep = dep_l[0]
            if(dep.rawtype == 'Depends'):
                deppackage = self.cache[dep.name]
                if(deppackage.is_installed == False):
                    totalsize += deppackage.candidate.size

        return totalsize

    #get the reviews object list of this application
    def get_reviews(self,page):
        if page in self.reviews:
            return self.reviews[page]
        else:
            return None

    #
    # 函数：添加评论信息
    #
    def add_reviews(self,page,reviewlist):
        if page not in self.reviews:
            self.reviews[page] = reviewlist

    #
    # 函数：更新软件缓存信息
    #
    def update_cache(self, apt_cache):
        # if not apt_cache:
        #     self.package = None
        # else:
        try:
            self.package = apt_cache[self.pkgname]
        except:
            self.package = None
        self.cache = apt_cache #every app has its own cache, it will take up too much memory or not ?

    # def set_status(self, context):
    #     self.init_status = context



if __name__ == "__main__":

    app = Application("gimp",None)


    cache = apt.Cache()
    cache.open()
    if (Globals.DEBUG_SWITCH):
        print(len(cache))
#   print cache
    for item in cache:
        if (Globals.DEBUG_SWITCH):
            #print("\n************************")
            #print("fullname:"+item.fullname)
            LogManager.INFO(_("fullname:"+item.fullname))
#           print "section:" +item.section
        if not item.candidate:
            continue
        if (Globals.DEBUG_SWITCH):
            #print(item.candidate.section)
            LogManager.INFO(_(str(item.candidate.section)))
        if "Icon" in item.candidate.record:
            if (Globals.DEBUG_SWITCH):
                #print("fullname:"+item.fullname)
                #print(item.candidate.record)
                LogManager.INFO(_("fullname:"+item.fullname))
                LogManager.INFO(_(str(item.candidate.record)))
#        print item.candidate.uri
     




import sys
import os
import shutil
from PIL import Image

def convertPixel(r, g, b, a=1):
    color = "#%02X%02X%02X" % (r, g, b)
    opacity = a
    return (color, opacity)

def png_to_svg(png_file_name,dest_path,pkgname):
    root, ext = os.path.splitext(png_file_name)
    root = dest_path + pkgname

    image = Image.open(png_file_name)
    mode = image.mode
    pixels = image.load()
    width, height = image.size

    if "RGB" in mode:
        output = "<svg width=\"%d\" height=\"%d\" viewBox=\"0 0 %d %d\" xmlns=\"http://www.w3.org/2000/svg\">" % (width,height,width, height)
        for r in range(height):
            print(r)
            for c in range(width):
                color, opacity = convertPixel(*pixels[c, r])
                output += "<rect x=\"%d\" y=\"%d\" width=\"1\" height=\"1\" fill=\"%s\" fill-opacity=\"%s\"/>" % (c, r, color, opacity)

        output += "</svg>"

        with open(root + ".svg", "w") as f:
            f.write(output)

    # shutil.copy(png_file_name,dest_path)



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.globals import Globals
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Download_Ranking_Widget(QWidget):
    def __init__(self,parent = None):
        QWidget.__init__(self,parent)
        self.init_ui()
        self.init_style()

    def init_ui(self):
        self.resize(237,550)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.local_lan = QLocale.system().name()
        self.titel_label = QLabel(self)
        self.titel_label.setAttribute(Qt.WA_TranslucentBackground)
        if self.local_lan == 'zh_CN':
            self.titel_label.resize(96,26)
        else:
            self.titel_label.resize(170,26)
        self.titel_label.move(0,0)

        self.more_btn = QPushButton(self)
        self.more_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.more_btn.setFocusPolicy(Qt.NoFocus)
        self.more_btn.setStyleSheet(
            "QPushButton{border: 0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;}")
        self.more_btn.setText(_("more"))
        self.more_btn.adjustSize()
        self.more_btn.move(self.width() - self.more_btn.width(),
                           self.titel_label.y() + int((self.titel_label.height() - self.more_btn.height()) / 2))
        self.more_btn.show()

        self.download_ranking_listWidget = QListWidget(self)
        self.download_ranking_listWidget.setFocusPolicy(Qt.NoFocus)
        self.download_ranking_listWidget.resize(237,508)
        self.download_ranking_listWidget.move(0,30)

    def init_style(self):
        if(Globals.THEME_COLOR == 0):
            self.titel_label.setStyleSheet("QLabel{font-size: 24px;font-weight: 500;color: #303133;line-height: 33px;}")
        else:
            self.titel_label.setStyleSheet( "QLabel{font-size: 24px;font-weight: 500;color: #F9F9F9;line-height: 33px;}")
        self.titel_label.setText(_("Down Rank"))
        # self.titel_label.adjustSize()
        self.download_ranking_listWidget.setStyleSheet("QListWidget{background-color:rgba(0,0,0,0);border:0px solid #cfcfcf;}QListWidget::item{background-color:rgba(0,0,0,0);height:65px;margin-top:0px;border:0px solid #cfcfcf;}QListWidget::item:hover{background-color:background-color:rgba(0,0,0,0);}")
        self.download_ranking_listWidget.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:rgb(255,255,255);border:0px;width:6px;}\
                                                                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                                                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                                                                 QScrollBar::sub-page:vertical{background-color:#EEEDF0;}\
                                                                                 QScrollBar::handle:vertical{background-color:rgba(0,0,0,20%);width:6px;border-radius:6px;} QScrollBar::handle:vertical:hover{background-color:rgb(0,0,0,10%);opacity:0.1;width:6px;border-radius:6px;}  QScrollBar::handle:vertical:pressed{background-color:rgb(0,0,0,50%);width:6px;border-radius:6px;}\
                                                                                 QScrollBar::add-page:vertical{background-color:#EEEDF0;}\
                                                                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                                                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")

    def get_applist(self,applist):
        self.applist = []
        self.applist.extend(applist)



#!/usr/bin/python3
# -*- coding: utf-8 -*-
__author__ = "huangsheng"

import os
import sys
# reload(sys)
# sys.setdefaultencoding('utf8')
# from models.enums import ERR_LOG,DEBUG_LOG,INFO_LOG,UKSC_CACHE_DIR_LOG

import logging
from logging import handlers
from xdg import BaseDirectory as xdg

UKSC_CACHE_DIR = os.path.join(xdg.xdg_cache_home, "uksc")
if not os.path.exists(UKSC_CACHE_DIR):
        try:
            os.makedirs(UKSC_CACHE_DIR)
        except OSError as e:
            pass
UKSC_CACHE_DIR_LOG = os.path.join(UKSC_CACHE_DIR,"log")
if not os.path.exists(UKSC_CACHE_DIR_LOG):
        try:
            os.makedirs(UKSC_CACHE_DIR_LOG)
        except OSError as e:
            pass
ERR_LOG = os.path.join(UKSC_CACHE_DIR_LOG,"kylin-software-center-error.log")
INFO_LOG = os.path.join(UKSC_CACHE_DIR_LOG,"kylin-software-center-info.log")
DEBUG_LOG = os.path.join(UKSC_CACHE_DIR_LOG,"kylin-software-center-debug.log")

class LogManager(object):
    level_relations = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'crit': logging.CRITICAL
    }  # 日志级别关系映射

    def __init__(self, filename, level='info', when="W0", backCount=1,
                 fmt='%(asctime)s - %(pathname)s[line:%(lineno)d] - %(levelname)s: %(message)s'):
        error_log_file = ERR_LOG.split("/")[len(ERR_LOG.split("/"))-1]
        info_log_file = INFO_LOG.split("/")[len(INFO_LOG.split("/")) - 1]
        debug_log_file = DEBUG_LOG.split("/")[len(DEBUG_LOG.split("/")) - 1]
        if(os.path.exists(UKSC_CACHE_DIR_LOG)):
            for file in os.listdir(UKSC_CACHE_DIR_LOG):
                if(file != info_log_file and file != error_log_file and file != debug_log_file):
                    os.remove(os.path.join(UKSC_CACHE_DIR_LOG,file))
        self.logger = logging.getLogger(filename)
        format_str = logging.Formatter(fmt)  # 设置日志格式
        self.logger.setLevel(self.level_relations.get(level))  # 设置日志级别
        # sh = logging.StreamHandler()  # 往屏幕上输出
        # sh.setFormatter(format_str)  # 设置屏幕上显示的格式
        th = handlers.TimedRotatingFileHandler(filename=filename, when=when, backupCount=backCount,
                                               encoding='utf-8')  # 往文件里写入#指定间隔时间自动生成文件的处理器
        # 实例化TimedRotatingFileHandler
        # interval是时间间隔，backupCount是备份文件的个数，如果超过这个个数，就会自动删除，when是间隔的时间单位，单位有以下几种：
        # S 秒
        # M 分
        # H 小时、
        # D 天、
        # W 每星期（interval==0时代表星期一）
        # midnight 每天凌晨
        th.setFormatter(format_str)  # 设置文件里写入的格式
        # self.logger.addHandler(sh)  # 把对象加到logger里
        self.logger.addHandler(th)

# class LogManager():
#     LOG = None
#
#     # @classmethod
#     # def INSTALL(self, msg):
#     #     try:
#     #         syslog.openlog("kylin-update-manager-install",syslog.LOG_PID,syslog.LOG_USER)
#     #         syslog.syslog(syslog.LOG_INFO, msg)
#     #         syslog.closelog()
#     #         return True
#     #     except Exception as e:
#     #         # print("syslog failed: ", e)
#     #         return False
#
#     @classmethod
#     def INFO(self, msg):
#         try:
#             syslog.openlog("kylin-software-center-info",syslog.LOG_PID,syslog.LOG_USER)
#             syslog.syslog(syslog.LOG_INFO, msg)
#             syslog.closelog()
#             return True
#         except Exception as e:
#             # print("syslog failed: ", e)
#             return False
#
#     # @classmethod
#     # def WARN(self, msg):
#     #     try:
#     #         syslog.openlog("kylin-update-manager-kum",syslog.LOG_PID,syslog.LOG_USER)
#     #         syslog.syslog(syslog.LOG_WARNING, msg)
#     #         syslog.closelog()
#     #         return True
#     #     except Exception as e:
#     #         # print("syslog failed: ", e)
#     #         return False
#
#     @classmethod
#     def ERR(self, msg):
#         try:
#             syslog.openlog("kylin-software-center-erro",syslog.LOG_PID,syslog.LOG_USER)
#             syslog.syslog(syslog.LOG_ERR, msg)
#             syslog.closelog()
#             return True
#         except Exception as e:
#             # print("syslog failed: ", e)
#             return False
#
#     # @classmethod
#     # def CRI(self, msg):
#     #     try:
#     #         syslog.openlog("kylin-update-manager-kum",syslog.LOG_PID,syslog.LOG_USER)
#     #         syslog.syslog(syslog.LOG_CRIT, msg)
#     #         syslog.closelog()
#     #         return True
#     #     except Exception as e:
#     #         # print("syslog failed: ", e)
#     #         return False
#
#
# #
# # 函数：初始化日志系统
# #
# # def init_log():
#
#     # cache_dir = os.environ.get('XDG_CACHE_HOME','').strip()
#     # if not cache_dir:
#     #     cache_dir = os.path.expanduser("~/.cache")
#     # log_file = os.path.join(cache_dir, "kum.log")
#     # LogManager.LOG = logging.getLogger("KUM")
#     # LogManager.LOG.propagate = False
#     # LogManager.LOG.setLevel(logging.DEBUG)
#     # log_handler = logging.handlers.RotatingFileHandler(log_file, maxBytes=1024*1024, backupCount=5)
#     # log_formatter = logging.Formatter("[%(asctime)s - %(levelname)s - %(message)s")
#     # log_handler.setFormatter(log_formatter)
#     # LogManager.LOG.addHandler(log_handler)
#



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import QWidget, QHBoxLayout, QLabel, QFrame, QApplication
from ui.systembutton import *
from models.globals import Globals
from models.enums import *
from ui.menubar import *
from utils import commontools
from ui.search_records import *
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class TitleBar(QFrame):
    first_click_range_menu = True
    change_mouse_statue = pyqtSignal()
    def __init__(self,width,mw,parent=None):
        QFrame.__init__(self, parent)
        self.ui_width = width
        self.m_parent = parent
        self.mw =mw
        self.click_item = False
        self.font = QFont()
        self.font.setPixelSize(14)
        self.m_font = QFontMetrics(self.font)
        self.pre_num = 0
        self.init_ui()

    def init_ui(self):
        self.resize(self.ui_width,85+10)
        self.setWindowFlags(Qt.FramelessWindowHint)
        # self.shadow_1 = QGraphicsBlurEffect(self)
        # self.shadow_1.setBlurRadius(80)
        # self.shadow_1.setBlurHints(QGraphicsBlurEffect.PerformanceHint)
        # self.setGraphicsEffect(self.shadow_1)

        # self.logo_icon_label = QLabel(self)
        # self.logo_icon_label.setFixedSize(24, 24)
        # self.logo_icon_label.setFrameShape(QFrame.NoFrame)
        # self.logo_icon_label.setAutoFillBackground(True)
        # self.logo_icon_label.setScaledContents(True)

        self.logo_icon_label = QPushButton(self)
        self.logo_icon_label.setFixedSize(24, 24)
        # self.logo_icon_label.setFrameShape(QFrame.NoFrame)
        self.logo_icon_label.setAutoFillBackground(True)
        # self.logo_icon_label.setScaledContents(True)
        iconpath = commontools.get_title_icon(Globals.APPNAME)
        self.logo_icon_label.setIcon(QIcon(iconpath))
        self.logo_icon_label.setIconSize(QSize(24, 24))
        self.logo_icon_label.setStyleSheet("QPushButton{background:transparent;border:0px;}")

        # appPicture = new
        # QPushButton(this); // 窗体左上角标题图片
        # appPicture->setIcon(QIcon::fromTheme("kylin-recorder", QIcon(":/png/png/recording_32.png")));
        # appPicture->setFixedSize(25, 25);
        # appPicture->setIconSize(QSize(25, 25)); // 重置图标大小
        # self.label_pixmap = icon.pixmap(8,8)
        # self.label_pixmap = QPixmap(icon)
        # self.logo_icon_label.setPixmap(QIcon.fromTheme("kylin-sotfware-center").pixmap(24,24))
        # for path in QIcon.themeSearchPaths():
        #     print("%s/%s" % (path, QIcon.themeName()))


        # iconpath = commontools.get_big_icon_path(Globals.APPNAME)
        # self.label_pixmap = QPixmap(iconpath)
        # self.logo_icon_label.setPixmap(self.label_pixmap)
        self.logo_icon_label.move(8,8)
        self.logo_icon_label.show()

        self.title_label = QLabel(self)
        self.title_label.resize(204,20)
        self.title_label.setAttribute(Qt.WA_TranslucentBackground)
        self.title_label.setText(_("Software Store"))
        self.title_label.move(self.logo_icon_label.x()+self.logo_icon_label.width()+8,10)
        self.title_label.show()

        self.search_label = QFrame(self)
        #self.search_label.setAttribute(Qt.WA_TranslucentBackground)
        self.search_label.setFixedSize(232,32)
        # self.search_label.setStyleSheet("QFrame{background: #ECECEC;font-size: 14px;font-weight: 500;color: #303133;line-height: 20px;border-radius: 16px;}")
        self.search_label.move(int((self.width()-self.search_label.width())/2),5)
        self.search_label.hide()

        self.all_search_tip_label = QLabel(self)
        self.all_search_tip_label.setAlignment(Qt.AlignLeft)
        self.all_search_tip_label.setStyleSheet("QLabel{font-size: 12px;font-weight: 400;color: #F56C6C;line-height: 17px;}")
        self.all_search_tip_label.setText(_("Full cache search: search applications from software sources, there may be unavailable or quality problems"))
        self.all_search_tip_label.adjustSize()
        self.all_search_tip_label.setFixedHeight(17)
        self.all_search_tip_label.move(self.search_label.x(), self.search_label.y() + self.search_label.height() + 4)
        self.all_search_tip_label.hide()

        self.search_type_label = QPushButton(self.search_label)
        self.search_type_label.setAttribute(Qt.WA_TranslucentBackground)
        self.search_type_label.setFocusPolicy(Qt.NoFocus)
        self.search_type_label.setFixedSize(53,32)
        self.search_type_label.move(0,0)
        self.search_type_label.setStyleSheet("QPushButton{border:0px;background: transparent;font-size: 14px;text-align: center;font-weight: 500;color: #303133;line-height: 20px;border-radius: 16px;}")
        self.search_type_label.clicked.connect(self.slot_click_type_btn)
        self.search_type_label.hide()

        self.search_type = QLabel(self.search_type_label)
        self.search_type.setAttribute(Qt.WA_TranslucentBackground)
        self.search_type.setFixedSize(39,32)
        self.search_type.setAlignment(Qt.AlignCenter)
        self.search_type.setText(_("Chc"))
        # self.search_type.setStyleSheet("QLabel{border:0px;font-size: 12px;font-weight: 400;color: #8F9399;line-height: 12px;}")
        self.search_type.move(3,0)
        self.search_type.hide()

        self.search_down_btn = QLabel(self.search_type_label)
        # self.search_down_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.search_down_btn.setFixedSize(13,12)
        # self.search_down_btn.setStyleSheet("QLabel{border:0px;background-image:url(./res/down.png);background-color:transparent;border:0px;}")
        self.search_down_btn.move(self.search_type_label.width()-self.search_down_btn.width(),int((self.search_type_label.height()-self.search_down_btn.height())/2))


        self.senior_search = Search_records(120,self.mw)
        self.senior_search.move(self.search_label.x(),self.search_label.y() + self.search_label.height())
        item1 = QListWidgetItem()
        list_item1 = line_widget(116,self.senior_search)
        list_item1.appname_label.hide()
        list_item1.appname_label.setText(_("All"))
        list_item1.appname_label.adjustSize()
        list_item1.appname_label.move(list_item1.appname_label.x(),int((list_item1.height()-list_item1.appname_label.height())/2))
        list_item1.appname_label.show()
        self.senior_search.item_list_widget.addItem(item1)
        self.senior_search.item_list_widget.setItemWidget(item1, list_item1)
        item2 = QListWidgetItem()
        list_item2 = line_widget(116,self.senior_search)
        list_item2.appname_label.hide()
        list_item2.appname_label.setText(_("Chc"))
        list_item2.appname_label.adjustSize()
        list_item2.appname_label.move(list_item2.appname_label.x(),
                                      int((list_item2.height() - list_item2.appname_label.height()) / 2))
        list_item2.appname_label.show()
        self.senior_search.item_list_widget.addItem(item2)
        self.senior_search.item_list_widget.setItemWidget(item2, list_item2)
        self.senior_search.item_list_widget.setFixedHeight(2*list_item2.height())
        self.senior_search.item_list_widget.show()
        self.senior_search.widget.setFixedHeight(2*(list_item2.height()+2))
        self.senior_search.setFixedHeight(2*(list_item2.height()+2)+20)
        self.senior_search.show()
        self.senior_search.hide()
        self.senior_search.item_list_widget.itemClicked.connect(self.show_red_search)
        self.locale_lan = QLocale.system().name()


        self.line_label = QLabel(self.search_label)
        #self.line_label.setAttribute(Qt.WA_TranslucentBackground)
        self.line_label.setFixedSize(1,13)
        # self.line_label.setStyleSheet("QLabel{border:1px solid #8F9399;background-color:#8F9399;color:#535353;}")
        self.line_label.move(self.search_type_label.x()+self.search_type_label.width()+4,int((self.search_label.height()-self.line_label.height())/2))
        self.line_label.hide()

        self.search_line_back = QLabel(self.search_label)
        self.search_line_back.setText(_("Please enter appname"))
        # self.search_line.setMaxLength(30)
        # self.search_line_back.setAttribute(Qt.WA_TranslucentBackground)
        self.search_line_back.setEnabled(False)
        self.search_line_back.adjustSize()
        self.search_line_back.setFixedHeight(20)

        self.search_line = QLineEdit(self.search_label)
        self.search_line.setMaxLength(30)
        self.search_line.setAttribute(Qt.WA_TranslucentBackground)
        self.search_line.setFixedSize(180, 20)
        self.search_line.move(60, int((self.search_label.height() - self.search_line.height()) / 2))
        self.search_line.textChanged.connect(self.back_changed)
        self.search_line.textEdited.connect(self.back_changed)
        self.search_line.show()
        self.search_line.installEventFilter(self)
        self.search_line_back.installEventFilter(self)

        self.search_image = QPushButton(self.search_label)
        self.search_image.setFocusPolicy(Qt.NoFocus)
        self.search_image.setAttribute(Qt.WA_TranslucentBackground)
        self.search_image.setFixedSize(16, 16)
        self.search_image.move(12, int((self.search_label.height() - self.search_image.height()) / 2))
        # self.search_image.setStyleSheet(
        #     "QPushButton{border:0px;font-size:12px;color:#a0a0a0;text-align: center;image: url(./res/search.png);background-color: rgba(255, 0, 0, 0);}QPushButton:hover{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/search_2.png);background-color: rgba(255, 0, 0, 0);}QPushButton:pressed{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/search_2.png);background-color: rgba(255, 0, 0, 0);}")
        # self.search_line.setStyleSheet("QLineEdit{border:0px;font-size: 12px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
        self.search_line.move(self.search_image.x()+self.search_image.width(), int((self.search_label.height() - self.search_line.height()) / 2))
        self.search_line.show()
        self.search_line_back.move(self.search_image.x()+self.search_image.width()+5, int((self.search_label.height() - self.search_line_back.height()) / 2))
        self.search_line_back.show()
        self.search_image.show()

        # self.search_line_back.setFixedSize(self.search_image.x()-self.search_line_back.x()-5, 20)

        self.search_cancel_btn = QPushButton(self.search_label)
        self.search_cancel_btn.setFocusPolicy(Qt.NoFocus)
        self.search_cancel_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.search_cancel_btn.setFixedSize(16, 16)
        self.search_cancel_btn.move(self.search_label.width()-self.search_cancel_btn.width()-10, int((self.search_label.height() - self.search_cancel_btn.height()) / 2))
        self.search_cancel_btn.setStyleSheet(
            "QPushButton{border:0px;font-size:12px;color:#a0a0a0;text-align: center;image: url(./res/eliminate.png);background-color: rgba(255, 0, 0, 0);}QPushButton:hover{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/eliminate.png);background-color: rgba(255, 0, 0, 0);}QPushButton:pressed{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/eliminate.png);background-color: rgba(255, 0, 0, 0);}")
        self.search_cancel_btn.hide()
        self.search_cancel_btn.clicked.connect(self.slot_click_search_cancel_btn)

        self.min_button = QPushButton(self)
        self.min_button.resize(30,30)
        self.min_button.setFocusPolicy(Qt.NoFocus)
        self.min_button.move(self.width() - 102, 4)
        self.min_button.setToolTip(_("mini"))
        self.set_button = QPushButton(self)
        self.set_button.resize(30,30)
        self.set_button.setFocusPolicy(Qt.NoFocus)
        self.set_button.setGeometry(self.width() - 136, 4, 30, 30)
        self.set_button.installEventFilter(self)
        self.set_button.setToolTip(_("menu"))
        self.max_button = QPushButton(self)
        self.max_button.resize(30, 30)
        self.max_button.setFocusPolicy(Qt.NoFocus)
        self.max_button.setGeometry(self.width() - 68, 4, 30, 30)
        # self.max_button.installEventFilter(self)
        self.max_button.setToolTip(_("max"))
        self.recovery_button = QPushButton(self)
        self.recovery_button.resize(30, 30)
        self.recovery_button.setFocusPolicy(Qt.NoFocus)
        self.recovery_button.setGeometry(self.width() - 68, 4, 30, 30)
        self.recovery_button.hide()
        self.recovery_button.installEventFilter(self)
        self.recovery_button.setToolTip(_("recovery"))
        self.close_button = QPushButton(self)
        self.close_button.resize(30,30)
        self.close_button.setFocusPolicy(Qt.NoFocus)
        self.close_button.setGeometry(self.width() - 34, 4, 30, 30)
        self.close_button.setToolTip(_("close"))


        self.login_btn = Login_Button(self)
        self.login_btn.resize(120,20)
        self.login_btn.init_ui()
        # self.login_btn.setLongTextToElideFormat(self.login_btn.user_name_label, Globals.LOGIN_ACCOUNT)
        self.login_btn.user_name_label.setText(_("Checking..."))
        self.login_btn.user_name_label.adjustSize()
        self.login_btn.user_name_label.setFixedWidth(self.login_btn.user_name_label.width())
        self.login_btn.user_name_label.resize(self.login_btn.user_name_label.width() + 3, 20)
        self.login_btn.btn.resize(self.login_btn.user_name_label.width() + 4 + self.login_btn.head_portrait_label.width(),20)
        self.login_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.login_btn.resize(self.login_btn.user_name_label.x()+self.login_btn.user_name_label.width(),20)
        self.login_btn.move(self.set_button.x()-10-self.login_btn.width(), 10)
        self.login_btn.btn.setStyleSheet("QPushButton{background:transparent;border:0px;border-radius: 4px;}")
        # self.login_btn.head_portrait_label.setStyleSheet("QLabel{border:0px;border-radius: 10px;}")
        self.login_btn.btn.setEnabled(False)
        self.login_btn.hide()

        self.exit_login_btn = Search_records(120,self.mw)
        # self.exit_login_btn.resize(120,20)
        item1 = QListWidgetItem()
        list_item1 = line_widget(116, self.exit_login_btn)
        list_item1.appname_label.hide()
        list_item1.appname_label.setText(_("User settings"))
        list_item1.appname_label.adjustSize()
        list_item1.appname_label.move(list_item1.appname_label.x(),
                                      int((list_item1.height() - list_item1.appname_label.height()) / 2))

        list_item1.appname_label.show()
        self.exit_login_btn.item_list_widget.addItem(item1)
        self.exit_login_btn.item_list_widget.setItemWidget(item1, list_item1)
        # self.exit_login_btn.resize(120,20)
        # item3 = QListWidgetItem()
        # list_item3 = line_widget(116, self.exit_login_btn)
        # list_item3.appname_label.hide()
        # list_item3.appname_label.setText(_("Scoring and comments"))
        # list_item3.appname_label.adjustSize()
        # list_item3.appname_label.move(list_item3.appname_label.x(),
        #                               int((list_item3.height() - list_item3.appname_label.height()) / 2))
        #
        # list_item3.appname_label.show()
        # self.exit_login_btn.item_list_widget.addItem(item3)
        # self.exit_login_btn.item_list_widget.setItemWidget(item3, list_item3)
        item2 = QListWidgetItem()
        list_item2 = line_widget(116, self.exit_login_btn)
        list_item2.appname_label.hide()
        list_item2.appname_label.setText(_("Exit login"))
        list_item2.appname_label.adjustSize()
        list_item2.appname_label.move(list_item2.appname_label.x(),
                                      int((list_item2.height() - list_item2.appname_label.height()) / 2))
        list_item2.appname_label.show()
        self.exit_login_btn.item_list_widget.addItem(item2)
        self.exit_login_btn.item_list_widget.setItemWidget(item2, list_item2)
        self.exit_login_btn.item_list_widget.setFixedHeight(2 * list_item2.height())
        self.exit_login_btn.item_list_widget.show()
        self.exit_login_btn.widget.setFixedHeight(2 * (list_item2.height() + 2))
        self.exit_login_btn.setFixedHeight(2 * (list_item2.height() + 2) + 20)
        self.exit_login_btn.show()
        self.exit_login_btn.hide()
        self.exit_login_btn.item_list_widget.itemClicked.connect(self.mw.slot_click_account_btn)
        self.exit_login_btn.move(self.login_btn.x(), self.login_btn.y() + self.login_btn.height() + 10)
        self.exit_login_btn.hide()

        self.return_btn = QPushButton(self)
        self.return_btn.setFocusPolicy(Qt.NoFocus)
        self.return_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.return_btn.resize(20,20)
        self.return_btn.move(32,62)
        # self.return_btn.setStyleSheet("QPushButton{border:0px;image: url(./res/return_btn.png);}")
        self.return_btn.hide()


        self.home_page_btn = QPushButton(self)
        self.home_page_btn.setAttribute(Qt.WA_TranslucentBackground)

        self.home_page_btn.setFocusPolicy(Qt.NoFocus)
        # self.home_page_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;font-size: 14px;font-weight: 400;color: #535353;text-align: center;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
        self.home_page_btn.setFixedSize(32,20)
        self.home_page_btn.setText(_("Discover"))
        self.home_page_btn.adjustSize()
        self.home_page_btn.move(76,57)
        self.home_page_btn.hide()
        self.home_page_label = QLabel(self)

        self.home_page_label.setStyleSheet("QLabel{border:0px;background: #3790FA;border-radius: 2px;}")
        self.home_page_label.move(79,81)
        self.home_page_label.hide()
        if self.locale_lan == "zh_CN":
            self.change_btn_width(self.home_page_btn)
            self.home_page_label.resize(self.home_page_btn.width() - 6, 4)
        else:
            self.change_btn_width(self.home_page_btn)
            self.home_page_label.resize(self.home_page_btn.width() - 6, 4)

        self.category_btn = QPushButton(self)
        self.category_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.category_btn.setFocusPolicy(Qt.NoFocus)
        # self.category_btn.setFixedSize(32, 20)
        # self.category_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
        self.category_btn.setText(_("Software"))
        self.category_btn.adjustSize()
        self.category_btn.move(self.home_page_btn.x()+self.home_page_btn.width()+30, 57)
        self.category_btn.hide()
        self.category_label = QLabel(self)
        # self.category_label.resize(self.category_btn.width()-5,4)
        self.category_label.setStyleSheet("QLabel{border:0px;background: #3790FA;border-radius: 2px;}")
        self.category_label.move(self.category_btn.x()+3,81)
        self.category_label.hide()
        if self.locale_lan == "zh_CN":
            # self.category_btn.setFixedSize(32,20)
            self.change_btn_width(self.category_btn)
            self.category_label.resize(self.category_btn.width() - 6, 4)
        else:
            # self.category_btn.setFixedSize(70, 20)
            self.change_btn_width(self.category_btn)
            self.category_label.resize(self.category_btn.width() - 6, 4)

        self.drive_btn = QPushButton(self)
        self.drive_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.drive_btn.setFocusPolicy(Qt.NoFocus)
        # self.category_btn.setFixedSize(32, 20)
        # self.drive_btn.setStyleSheet(
        #     "QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
        self.drive_btn.setText(_("Drive"))
        self.drive_btn.adjustSize()
        self.drive_btn.move(self.category_btn.x() + self.category_btn.width() + 30, 57)
        self.drive_btn.hide()
        self.drive_label = QLabel(self)
        # self.category_label.resize(self.category_btn.width()-5,4)
        self.drive_label.setStyleSheet("QLabel{border:0px;background: #3790FA;border-radius: 2px;}")
        self.drive_label.move(self.drive_btn.x() + 3, 81)
        self.drive_label.hide()
        if self.locale_lan == "zh_CN":
            self.change_btn_width(self.drive_btn)
            self.drive_label.resize(self.drive_btn.width() - 6, 4)
        else:
            self.change_btn_width(self.drive_btn)
            self.drive_label.resize(self.drive_btn.width() - 6, 4)

        self.kydroid_btn = QPushButton(self)
        self.kydroid_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.kydroid_btn.setFocusPolicy(Qt.NoFocus)
        # self.kydroid_btn.setFixedSize(32, 20)
        # self.kydroid_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;font-size: 14px;font-weight: 400;color: #535353;text-align: center;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
        self.kydroid_btn.setText(_("Mobile apps"))
        self.kydroid_btn.adjustSize()
        self.kydroid_btn.move(self.drive_btn.x()+self.drive_btn.width()+30,57)
        self.kydroid_btn.hide()
        self.kydroid_label = QLabel(self)
        # self.kydroid_label.resize(self.kydroid_btn.width()-5,4)
        self.kydroid_label.setStyleSheet("QLabel{border:0px;background: #3790FA;border-radius: 2px;}")
        self.kydroid_label.move(self.kydroid_btn.x()+3,81)
        self.kydroid_label.hide()
        if self.locale_lan == "zh_CN":
            # self.kydroid_btn.setFixedSize(56,20)
            self.change_btn_width(self.kydroid_btn)
            self.kydroid_label.resize(self.home_page_btn.width() - 6, 4)
            self.kydroid_label.move(self.kydroid_btn.x()+int((self.kydroid_btn.width()-self.kydroid_label.width())/2),81)
        else:
            # self.kydroid_btn.setFixedSize(82, 20)
            self.change_btn_width(self.kydroid_btn)
            self.kydroid_label.resize(self.kydroid_btn.width() - 6, 4)


        self.my_btn = QPushButton(self)
        self.my_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.my_btn.setFocusPolicy(Qt.NoFocus)
        # self.my_btn.setFixedSize(32, 20)
        # self.my_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;font-size: 14px;font-weight: 400;color: #535353;text-align: center;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
        self.my_btn.setText(_("My apps"))
        self.my_btn.adjustSize()
        self.my_btn.move(self.kydroid_btn.x()+self.kydroid_btn.width()+30, 57)
        self.my_btn.hide()
        self.my_label = QLabel(self)
        # self.my_label.setFixedSize(self.my_btn.width()-5,4)
        self.my_label.setStyleSheet("QLabel{border:0px;background: #3790FA;border-radius: 2px;}")
        self.my_label.move(self.my_btn.x()+3,81)
        self.my_label.hide()
        self.my_btn_tip = QLabel(self)
        self.my_btn_tip.setFixedSize(6, 6)
        self.my_btn_tip.setStyleSheet("QLabel{background: #F56C6C;border-radius:3px;font-size: 11px;font-weight: 400;color: #FFFFFF;text-align: center;line-height: 16px;}")
        self.my_btn_tip.move(self.my_btn.x() + self.my_btn.width() + 3 , self.my_btn.y()-3)
        self.my_btn_tip.setAlignment(Qt.AlignCenter)
        self.my_btn_tip.hide()
        if self.locale_lan == "zh_CN":
            # self.my_btn.setFixedSize(32,20)
            self.change_btn_width(self.my_btn)
            self.my_label.resize(self.my_btn.width() - 6, 4)
        else:
            # self.my_btn.setFixedSize(55, 20)
            self.change_btn_width(self.my_btn)
            self.my_label.resize(self.my_btn.width() - 6, 4)
        self.refresh_background_color()
        # self.home_page_btn.setEnabled(False)
        # self.my_btn.setEnabled(False)
        # self.drive_btn.setEnabled(False)
        # self.kydroid_btn.setEnabled(False)
        # self.category_btn.setEnabled(False)

    def back_changed(self,text = ""):
        if self.search_line.text() != '':
            self.search_cancel_btn.show()
            self.search_line_back.hide()
        else:
            self.search_cancel_btn.hide()
            self.search_line_back.show()

    def slot_editingFinished(self):
        self.search_line_back.hide()
            
    def re_move(self):
        self.close_button.hide()
        self.min_button.hide()
        # self.max_button.hide()
        self.logo_icon_label.move(8, 8)
        self.title_label.move(self.logo_icon_label.x() + self.logo_icon_label.width() + 8, 10)
        self.search_label.move(int((self.width() - self.search_label.width()) / 2), 5)
        self.senior_search.move(self.search_label.x(), self.search_label.y() + self.search_label.height())
        self.min_button.move(self.width() - 102, 4)
        self.set_button.setGeometry(self.width() - 136, 4, 30, 30)
        self.max_button.setGeometry(self.width() - 68, 4, 30, 30)
        self.recovery_button.setGeometry(self.width() - 68, 4, 30, 30)
        self.close_button.setGeometry(self.width() - 34, 4, 30, 30)
        self.login_btn.move(self.set_button.x() - 10 - self.login_btn.width(), 10)
        self.exit_login_btn.move(self.login_btn.x() , self.login_btn.y()+self.login_btn.height()+10)
        self.all_search_tip_label.move(self.search_label.x(), self.search_label.y() + self.search_label.height() + 4)
        self.return_btn.move(32, 62)
        self.home_page_btn.move(76, 57)
        self.home_page_label.move(79, 81)
        self.category_btn.move(self.home_page_btn.x() + self.home_page_btn.width() + 30, 57)
        self.category_label.move(self.category_btn.x() + 3, 81)
        if(self.drive_btn.isHidden() == False):
            self.drive_btn.move(self.category_btn.x()+self.category_btn.width()+30,57)
            self.drive_label.move(self.drive_btn.x()+3,81)
            self.kydroid_btn.move(self.drive_btn.x() + self.drive_btn.width() + 30, 57)
            self.kydroid_label.move(self.kydroid_btn.x()+int((self.kydroid_btn.width()-self.kydroid_label.width())/2),81)
            if(self.kydroid_btn.isHidden()):
                self.my_btn.move(self.kydroid_btn.x(), 57)
                self.my_label.move(self.my_btn.x() + 3, 81)
            else:
                self.my_btn.move(self.kydroid_btn.x() + self.kydroid_btn.width() + 30, 57)
                self.my_label.move(self.my_btn.x() + 3, 81)
        else:
            if(self.home_page_btn.isHidden() == True):
                self.drive_btn.move(self.category_btn.x() + self.category_btn.width() + 30, 57)
                self.drive_label.move(self.drive_btn.x() + 3, 81)
                self.kydroid_btn.move(self.drive_btn.x() + self.drive_btn.width() + 30, 57)
                self.kydroid_label.move(
                    self.kydroid_btn.x() + int((self.kydroid_btn.width() - self.kydroid_label.width()) / 2), 81)
                if (self.kydroid_btn.isHidden()):
                    self.my_btn.move(self.kydroid_btn.x(), 57)
                    self.my_label.move(self.my_btn.x() + 3, 81)
                else:
                    self.my_btn.move(self.kydroid_btn.x() + self.kydroid_btn.width() + 30, 57)
                    self.my_label.move(self.my_btn.x() + 3, 81)
            else:
                self.kydroid_btn.move(self.category_btn.x() + self.category_btn.width() + 30, 57)
                self.kydroid_label.move(self.kydroid_btn.x()+int((self.kydroid_btn.width()-self.kydroid_label.width())/2),81)
                if (self.kydroid_btn.isHidden()):
                    self.my_btn.move(self.kydroid_btn.x(), 57)
                    self.my_label.move(self.my_btn.x() + 3, 81)
                else:
                    self.my_btn.move(self.kydroid_btn.x() + self.kydroid_btn.width() + 30, 57)
                    self.my_label.move(self.my_btn.x() + 3, 81)
        self.my_btn_tip.move(self.my_btn.x() + self.my_btn.width() + 3, self.my_btn.y() - 3)
        self.close_button.show()
        self.min_button.show()
        # if(self.max_button.isHidden()):
        #     self.recovery_button.show()
        #     self.max_button.hide()
        # else:
        #     self.recovery_button.hide()
        #     self.max_button.show()

    def show_exit_login_widget(self):
        self.login_btn.init_ui()
        self.refresh_background_color()

    def slot_click_type_btn(self):
        self.mw.hide_tip_widget()
        if(self.senior_search.isHidden() == True):
            self.senior_search.item_list_widget.show()
            self.senior_search.show()
        else:
            self.senior_search.item_list_widget.hide()
            self.senior_search.hide()

    def change_btn_width(self,label):
        s = self.m_font.boundingRect(label.text()).size().width()
        label.setFixedSize(s, 22)


    def change_icon(self,status):
        if(status == BUTTON_LEAVE):
            if(Globals.THEME_COLOR == 0):
                self.exit_login_btn.head_portrait_label.setStyleSheet(
                    "QLabel{border:0px;border-radius: 10px;background-image:url(./res/exit_login.png); background-position:center;}")
                self.exit_login_btn.user_name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;line-height: 20px;}")
            else:
                self.exit_login_btn.user_name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;}")
                self.exit_login_btn.head_portrait_label.setStyleSheet("QLabel{border:0px;border-radius: 10px;background-image:url(./res/exit_login_dark.png);background-position:center;}")
        else:
            self.exit_login_btn.head_portrait_label.setStyleSheet(
                "QLabel{border:0px;border-radius: 10px;background-image:url(./res/exit_login1.png);background-position:center;}")
            self.exit_login_btn.user_name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F56C6C;line-height: 20px;}")

    #
    #函数：重新设置icon
    #
    def change_icon_show(self):
        iconpath = commontools.get_title_icon(Globals.APPNAME)
        self.logo_icon_label.setIcon(QIcon(iconpath))
        self.logo_icon_label.setIconSize(QSize(24, 24))
        self.logo_icon_label.setStyleSheet("QPushButton{background:transparent;border:0px;}")
        pass
        # iconpath = commontools.get_big_icon_path(Globals.APPNAME)
        # self.label_pixmap = QPixmap(iconpath)
        # self.logo_icon_label.setPixmap(self.label_pixmap)
        # self.logo_icon_label.hide()
        # self.logo_icon_label.show()

    #
    #函数：刷新背景颜色
    #
    def refresh_background_color(self):
        if (Globals.THEME_COLOR == 0):
            self.min_button.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/mini1.png')}QPushButton:hover{border:0px;border-image:url('res/mini2.png')}QPushButton:pressed{border:0px;border-image:url('res/mini3.png')}")
            self.set_button.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/set1.png')}QPushButton:hover{border:0px;border-image:url('res/set2.png')}QPushButton:pressed{border:0px;border-image:url('res/set3.png')}")
            self.close_button.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
            self.max_button.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/max1.png')}QPushButton:hover{border:0px;border-image:url('res/max2.png')}QPushButton:pressed{border:0px;border-image:url('res/max3.png')}")
            self.recovery_button.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/recovery1.png')}QPushButton:hover{border:0px;border-image:url('res/recovery2.png')}QPushButton:pressed{border:0px;border-image:url('res/recovery3.png')}")
            if(Globals.RIGHT_ANGLE):
                self.setStyleSheet("QFrame{background-color: #ffffff;}")
            else:
                self.setStyleSheet("QFrame{background-color: #ffffff;border-top-left-radius:12px;border-top-right-radius:12px;}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #303133;font-weight: 500;}")
            self.search_label.setStyleSheet(
                "QFrame{background: #ECECEC;font-size: 14px;font-weight: 500;color: #8F9399;line-height: 20px;border-radius: 16px;}")
            self.line_label.setStyleSheet("QLabel{border:1px solid #8F9399;background-color:#8F9399;color:#535353;}")
            self.search_type.setStyleSheet("QLabel{border:0px;font-size: 12px;font-weight: 400;color: #8F9399;line-height: 12px;}")
            self.search_down_btn.setStyleSheet(
                "QLabel{border:0px;background-image:url(./res/down.png);background-color:transparent;border:0px;}")
            self.search_line_back.setStyleSheet(
                "QLabel{border:0px;font-size: 12px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")

            self.search_line.setStyleSheet("QLineEdit{border:0px;font-size: 12px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
            self.search_image.setStyleSheet(
                "QPushButton{border:0px;font-size:12px;color:#a0a0a0;text-align: center;image: url(./res/search.png);background-color: rgba(255, 0, 0, 0);}QPushButton:hover{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/search_2.png);background-color: rgba(255, 0, 0, 0);}QPushButton:pressed{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/search_2.png);background-color: rgba(255, 0, 0, 0);}")
            self.login_btn.user_name_label.setStyleSheet("QLabel{font-size: 14px;border:0px;font-weight: 400;color: #303133;line-height: 20px;border-radius: 0px;}")

            if(Globals.USER_PROFILE == ''):
                user_profile = UBUNTUKYLIN_RES_PATH + "unlogin.png"
                pix2 = QPixmap(user_profile)
                fitpixmap_userIcon = pix2.scaled(20, 20, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
                fitpixmap_userIcon = self.PixmapToRound(fitpixmap_userIcon, 20,
                                                        20)
                self.login_btn.head_portrait_label.setPixmap(fitpixmap_userIcon)
                # self.login_btn.head_portrait_label.setStyleSheet("QLabel{border:0px;border-radius: 10px;background-image:url(./res/unlogin.png)}")
            self.home_page_btn.setStyleSheet(
                "QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.category_btn.setStyleSheet(
                "QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.kydroid_btn.setStyleSheet(
                "QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.drive_btn.setStyleSheet(
                "QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.my_btn.setStyleSheet(
                "QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #535353;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.return_btn.setStyleSheet("QPushButton{border:0px;image: url(./res/return_btn.png);}")
        else:
            self.min_button.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-minimize-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-minimize-white.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-minimize-white.png')}")
            self.set_button.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-more-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-more-white.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-more-white.png')}")
            self.close_button.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-close.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-close.png')}")
            self.max_button.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-maximize-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-maximize-white.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-maximize-white.png')}")
            self.recovery_button.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-restore-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-restore-white.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-restore-white.png')}")
            if (Globals.RIGHT_ANGLE):
                self.setStyleSheet("QFrame{background-color: #2F3032;}")
            else:
                self.setStyleSheet("QFrame{background: #2F3032;border-top-left-radius:12px;border-top-right-radius:12px;}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #F9F9F9;line-height: 20px;font-weight: 500;}")
            self.line_label.setStyleSheet("QLabel{border:1px solid rgba(143, 147, 153, 1);background-color:rgba(143, 147, 153, 1);}")
            self.search_type.setStyleSheet("QLabel{border:0px;font-size: 12px;font-weight: 400;color: #F9F9F9;line-height: 12px;}")
            self.search_label.setStyleSheet(
                "QFrame{background: rgba(255, 255, 255, 0.08);font-size: 14px;font-weight: 500;color: #8F9399;line-height: 20px;border-radius: 16px;}")
            self.search_down_btn.setStyleSheet("QLabel{border:0px;background-image:url(./res/down.png);background-color:transparent;}")
            self.search_line_back.setStyleSheet(
                "QLabel{border:0px;font-size: 12px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
            self.search_line.setStyleSheet("QLineEdit{border:0px;font-size: 12px;font-weight: 400;color: #ffffff;line-height: 16px;border:0px;background-color: transparent;}")
            self.search_image.setStyleSheet("QPushButton{border:0px;font-size:12px;color:#a0a0a0;text-align: center;image: url(./res/search_dark.png);background-color: rgba(255, 0, 0, 0);}QPushButton:hover{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/search_2.png);background-color: rgba(255, 0, 0, 0);}QPushButton:pressed{border:0px;font-size:12px;color:#a0a0a0;image: url(./res/search_2.png);background-color: rgba(255, 0, 0, 0);}")
            self.login_btn.user_name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;line-height: 20px;}")
            if (Globals.USER_PROFILE == ''):
                user_profile = UBUNTUKYLIN_RES_PATH + "unlogin_dark.png"
                pix2 = QPixmap(user_profile)
                fitpixmap_userIcon = pix2.scaled(20, 20, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
                fitpixmap_userIcon = self.PixmapToRound(fitpixmap_userIcon, 20, 20)
                self.login_btn.head_portrait_label.setPixmap(fitpixmap_userIcon)
                # self.login_btn.head_portrait_label.setStyleSheet("QLabel{border:0px;border-radius: 10px;background-image:url(./res/unlogin_dark.png);background-position:center;}")
            self.home_page_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #C0C4CC;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.category_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #C0C4CC;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.drive_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #C0C4CC;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.kydroid_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #C0C4CC;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.my_btn.setStyleSheet("QPushButton{border:0px;background-color:transparent;text-align: center;font-size: 14px;text-align: center;font-weight: 400;color: #C0C4CC;line-height: 20px;}QPushButton:hover{color:#3790FA;font-weight: 400;};QPushButton:pressed{color:#3790FA;font-weight: 500;}")
            self.return_btn.setStyleSheet("QPushButton{border:0px;image: url(./res/return_btn_dark.png);}")
        if(self.my_label.isHidden() == False):
            self.mw.set_title_btn_stylesheet(PageStates.MYPAGE)
        elif(self.kydroid_label.isHidden() == False):
            self.mw.set_title_btn_stylesheet(PageStates.KYDROID)
        elif (self.home_page_label.isHidden() == False):
            self.mw.set_title_btn_stylesheet(PageStates.HOMEPAGE)
        elif (self.category_label.isHidden() == False):
            self.mw.set_title_btn_stylesheet(PageStates.CAREGORYPAGE)
        self.exit_login_btn.slot_show_dark_mode()
        self.senior_search.slot_show_dark_mode()
        # QApplication.processEvents()


    def slot_click_search_cancel_btn(self):
        self.search_line.clear()
        self.search_line_back.show()
        self.search_cancel_btn.hide()

    def show_red_search(self,search_type):
        Globals.ADVANCED_SEARCH = search_type
        self.senior_search.hide()

    def eventFilter(self, widget, event):
        if widget == self.search_line:
            if(event.type() == event.MouseButtonPress):
                self.senior_search.hide()
            elif(event.type() == event.FocusAboutToChange):
                if(self.search_line.text() == ''):
                    self.search_cancel_btn.hide()
                    self.search_line_back.show()
                else:
                    self.search_cancel_btn.show()
                    self.search_line_back.hide()
            elif(event.type() == event.KeyRelease):
                if self.search_line.text() == '':
                    if(Qt.Key_A <= event.key() <= Qt.Key_Z or Qt.Key_0 <= event.key() <= Qt.Key_9):
                        if (event.key() == Qt.Key_X):
                            if QApplication.keyboardModifiers() == Qt.ControlModifier:
                                self.search_cancel_btn.hide()
                                self.search_line_back.show()
                        elif (event.key() == Qt.Key_C):
                            if QApplication.keyboardModifiers() == Qt.ControlModifier:
                                self.search_cancel_btn.hide()
                                self.search_line_back.show()
                        elif (event.key() == Qt.Key_Z):
                            if QApplication.keyboardModifiers() == Qt.ControlModifier:
                                self.search_cancel_btn.hide()
                                self.search_line_back.show()
                        else:
                            self.search_cancel_btn.show()
                            self.search_line_back.hide()
                            self.pre_num +=1
                    elif(Qt.Key_Backspace == event.key()):
                        if self.search_line.text() == '':
                            if(self.pre_num != 0):
                                self.pre_num -=1
                            else:
                                self.search_cancel_btn.hide()
                                self.search_line_back.show()
                            if(self.pre_num == 0):
                                self.search_cancel_btn.hide()
                                self.search_line_back.show()
                        else:
                            self.search_cancel_btn.show()
                            self.search_line_back.hide()
                else:
                    self.search_cancel_btn.show()
                    self.search_line_back.hide()
                    self.pre_num = 0
                if(Qt.Key_Return == event.key() or Qt.Key_Enter == event.key() or Qt.Key_Space == event.key()):
                    if self.search_line.text() == '':
                        self.search_cancel_btn.hide()
                        self.search_line_back.show()
                    else:
                        self.search_cancel_btn.show()
                        self.search_line_back.hide()
                        self.pre_num = 0
        if(hasattr(self,"search_line_back")):
            if widget == self.search_line_back:
                if(event.type() == event.MouseButtonPress):
                    self.search_line.setFocus(True)
        if(hasattr(self,"max_button") and hasattr(self,"recovery_button") and hasattr(self,"set_button")):
            if widget == self.max_button :
                if(event.type() == event.MouseButtonPress):
                    self.mw.slot_click_max_btn()
                    return True
                if(event.type() == event.MouseButtonRelease):
                    return True
            if widget == self.recovery_button and event.type() == event.MouseButtonPress:
                return True
            if (widget == self.recovery_button and event.type() == event.MouseButtonRelease):
                self.mw.slot_click_recovery_btn()
                return True
            if (widget == self.recovery_button and event.type() == event.Enter):
                if(Globals.THEME_COLOR == 0):
                    self.recovery_button.setStyleSheet(
                        "QPushButton{border-radius: 4px;border:0px;border-image:url('res/recovery1.png')}QPushButton:hover{border:0px;border-image:url('res/recovery2.png')}QPushButton:pressed{border:0px;border-image:url('res/recovery3.png')}")
                else:
                    self.recovery_button.setStyleSheet(
                        "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-restore-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-restore-white.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-restore-white.png')}")

            if (widget == self.set_button and event.type() == event.MouseButtonRelease ):
                self.mw.slot_click_set_button()
        return False


    def enterEvent(self, event):
        self.mw.setCursor(Qt.ArrowCursor)


     #将图片切割成圆角
    def PixmapToRound(self,src,x,y):
        pixmapa = QPixmap(src)
        pixmap = QPixmap(x, y)
        pixmap.fill(Qt.transparent)
        painter = QPainter(pixmap)
        painter.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
        path = QPainterPath()
        rect = QRectF(0,0,x,y)
        path.addRoundedRect(rect, 10.0, 10.0)
        painter.setClipPath(path)
        painter.drawPixmap(0, 0, x, y, pixmapa)

        return pixmap


class Login_Button(QFrame):
    status_changed = pyqtSignal(int)
    def __init__(self,parent = None):
        QFrame.__init__(self, parent)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.setFocusPolicy(Qt.NoFocus)
        self.setStyleSheet("QFrame{border:0px;background: #F6F6F6;border-radius: 4px;}")
        self.resize(120,39)

        self.btn = QPushButton(self)
        self.btn.setAttribute(Qt.WA_TranslucentBackground)
        self.btn.setFocusPolicy(Qt.NoFocus)
        self.btn.setStyleSheet("QPushButton{background:#ffffff;border:0px;border-radius: 4px;text-align: center;}QPushButton:hover{background:#F7F7F7;border:0px;}QPushButton:pressed{background:#F7F7F7;border:0px;}")
        self.btn.resize(self.width(),20)
        self.btn.move(0,0)


        self.head_portrait_label = QLabel(self.btn)
        self.head_portrait_label.resize(20, 20)
        # self.head_portrait_label.setAttribute(Qt.WA_TranslucentBackground)

        self.user_name_label = QLabel(self.btn)
        self.user_name_label.setAttribute(Qt.WA_TranslucentBackground)
        self.user_name_label.setAlignment(Qt.AlignVCenter)
        # self.user_name_label.setMaximumWidth(95)
        self.user_name_label.setFixedWidth(65)
        # self.user_name_label.maximumWidth()
        self.user_name_label.setFixedHeight(20)
        # self.user_name_label.resize(95, 20)
        self.user_name_label.show()
        self.init_ui()

    def init_ui(self):
        self.head_portrait_label.setStyleSheet("QLabel{border:0px;border-radius: 10px;}")
        self.head_portrait_label.move(0, int((self.btn.height()-self.head_portrait_label.height())/2))
        self.head_portrait_label.show()
        self.user_name_label.setStyleSheet( "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #303133;line-height: 20px;}")
        self.user_name_label.setAttribute(Qt.WA_TranslucentBackground)
        self.user_name_label.setText(_("login"))
        self.user_name_label.adjustSize()
        self.user_name_label.resize(self.user_name_label.width() +1,20)
        self.btn.resize(self.user_name_label.width() +4 +self.head_portrait_label.width(),20)
        self.user_name_label.move(24,int((self.btn.height()-self.user_name_label.height())/2))


    def setLongTextToElideFormat(self,label, te):
        te = te.replace("\n",",").replace("\r","").replace("\t","")
        metrics = QFontMetrics(label.font())
        elidedText = metrics.elidedText(te, Qt.ElideRight, label.maximumWidth())

        # label.document().adjustSize()
        label.setText(elidedText)

# 鼠标进入事件
    def enterEvent(self, event):
        self.status = BUTTON_ENTER
        self.status_changed.emit(BUTTON_ENTER)


    #
    # 函数：鼠标离开事件
    #
    def leaveEvent(self, event):
        self.status = BUTTON_LEAVE
        self.status_changed.emit(BUTTON_LEAVE)
